"""
Configuration of keyword color highlighting which also contains regexes used to identify
email sendersa and recipients in email headers.
"""
import re
from typing import Sequence

from rich.console import Console
from rich.text import Text

from epstein_files.documents.config.categories.legal import EPSTEIN_V_ROTHSTEIN_EDWARDS
from epstein_files.documents.documents.categories import (CATEGORY_STYLES, CATEGORY_STYLE_MAPPING,
     DEFAULT_CATEGORY_STYLE, Interesting, Neutral, Uninteresting)
from epstein_files.documents.emails.constants import (ALL_HEADER_PATTERNS, QUOTE_INDENT_CHAR_GROUP, REPLY_REGEX,
     SENT_FROM_REGEX, XML_STRIPPED_MSG)
from epstein_files.output.highlighted_names import HighlightGroup, HighlightedNames, HighlightPatterns, ManualHighlight
from epstein_files.people.contact import Contact, acronym, organization, epstein_co, epstein_trust, law_enforcement
from epstein_files.people.names import *
from epstein_files.util.constant.strings import *
from epstein_files.util.constant.urls import SUBSTACK_INSIGHTS_POD
from epstein_files.util.env import args
from epstein_files.util.helpers.data_helpers import flatten
from epstein_files.util.helpers.string_helper import indented
from epstein_files.util.logging import logger

CIVIL_ATTORNEY = 'civil attorney'
CRIMINAL_DEFENSE_ATTORNEY = 'criminal defense attorney'
CRIMINAL_DEFENSE_2008 = f"Epstein {CRIMINAL_DEFENSE_ATTORNEY} on 2008 case"
EPSTEIN_V_ROTHSTEIN_EDWARDS_ATTORNEY = f"{CIVIL_ATTORNEY} in {EPSTEIN_V_ROTHSTEIN_EDWARDS}"
ESTATE_EXECUTOR = 'estate executor'
EPSTEIN_ESTATE_EXECUTOR = f"Epstein {ESTATE_EXECUTOR}"
JUNKERMANN_FUND = f"{NICOLE_JUNKERMANN}'s fund, invested in China, online poker, Russian run Euro bank Revolut"
JEAN_LUC_MC2 = f"{JEAN_LUC_BRUNEL}'s {MC2_MODEL_MGMT}"
QUESTION_MARKS_TXT = Text(QUESTION_MARKS, style='grey50')
ROTHSTEIN_ROSENFELDT_ADLER_ATTORNEY = f"{ROTHSTEIN_ROSENFELDT_ADLER} attorney"
THIELS_VALAR = f"{PETER_THIEL}'s {VALAR_VENTURES}"
WIGDOR_ATTORNEY = f"Wigdor LLP lawyer in {LEON_BLACK} lawsuit"

FINANCIAL_COLOR = 'dark_sea_green2'
VICTIM_COLOR = 'orchid1'

DATE_PATTERN = r"\d{1,4}[-/]\d{1,2}[-/]\d{2,4}"
TIME_PATTERN = r"\d{1,2}:\d{2}:\d{2}( [AP]M)?"

debug_console = Console(color_system='256')


HIGHLIGHT_GROUPS: Sequence[HighlightGroup] = [
    # These have to come first to get both stylings applied to the email subjects
    ManualHighlight(
        label='email_subject',
        style='light_yellow3',
        pattern=r"^(> )?(Classification|Flag|Objet\s?|Subject|Sujet\s?): (?P<email_subject>.*)",
    ),
    ManualHighlight(
        label='legal_question',
        style='wheat4',
        pattern=r"^(Q\. )(?P<legal_question>.{,500}?)(?=^A\.)",
        regex_flags=re.DOTALL | re.MULTILINE,
    ),

    # Names
    HighlightedNames(
        label=Uninteresting.ACADEMIA,
        style='light_goldenrod2',
        contacts=[
            Contact(BEN_GOERTZEL, 'AI researcher, Humanity+ chairman, iCog Labs, funded by Epstein'),
            Contact('Brian Greene', 'physicist at Columbia University', match_partial=None),
            Contact('Daniel Kahneman', "Nobel economic sciences laureate and cognitivie psychologist (?)", r"Dan(iel|ny) Kahneman"),
            Contact(
                DANIEL_SCHMACHTENBERGER,
                "founder of Civilization Research Institute",
                link_to_bio='https://civilizationemerging.com/about/',
            ),
            Contact(DAVID_HAIG, "evolutionary geneticist?", emailer_pattern=r"David Haig|Haig, David"),
            Contact('David Grosof', "MIT Sloan School of Management"),
            Contact('Ed Boyden', f"{MIT_MEDIA_LAB} neurobiology"),
            Contact(
                'Elkhonon Goldberg',
                f"Neuropsychologist, arranged Moscow University meetings",
                r"(Dr\.?|Elkhonon) Goldberg",
                match_partial='first',
            ),
            Contact('Harry Fisch', "men's health expert at New York-Presbyterian / Weill Cornell (?)"),
            Contact(
                JAMES_TAGG,
                "The Penrose Institute, Sunlight Aerospace, claims to be inventor of the eSIM",
                link_to_bio='https://www.sunlightx.com/james-tagg'
            ),
            Contact('James Watson', 'one of the discoverers of DNA', match_partial=None),
            Contact(JEM_BENDELL, 'board member of Community Forge, provider of alternative currency software', match_partial='both'),
            Contact(JOSCHA_BACH, "cognitive science / AI research", match_partial='both'),
            Contact(
                LAWRENCE_KRAUSS,
                "theoretical physicist with #MeToo problems",
                r"Lawrence Kraus[es]?|[jl]awkrauss|kruase",
                link_to_bio='https://www.theatlantic.com/science/archive/2018/10/lawrence-krauss-sexual-misconduct-me-too-arizona-state/573844/',
            ),
            Contact('Lee Smolin', 'physicist'),
            Contact(LINDA_STONE, f"ex-Microsoft, {MIT_MEDIA_LAB}", match_partial=None),
            Contact(MARK_TRAMO, "professor of neurology at UCLA"),
            Contact('Marvin Minsky', 'mathematician, early AI researcher'),
            Contact('Nancy Dahl', f"wife of {LAWRENCE_KRAUSS}"),
            Contact(NEAL_KASSELL, "professor of neurosurgery at University of Virginia"),
            Contact('Neri Oxman', f"MIT, wife of Bill Ackman", match_partial='both'),
            Contact('Nicholas Christakis', f"Yale professor of Social and Natural Science"),
            Contact(NOAM_CHOMSKY, "professor of linguistics at MIT", match_partial='both'),
            Contact('Norman Finkelstein', "scholar, well known critic of Israel", match_partial=None),
            Contact(PETER_ATTIA, "longevity medicine"),
            Contact(ROBERT_TRIVERS, "evolutionary biology", r"tri[vy]ersr@gmail|Robert Trivers?"),
            Contact(ROGER_SCHANK, "AI pioneer, Teachers College, Columbia University, deceased"),
            Contact('Sandy Pentland', MIT_MEDIA_LAB, r"((Alex|Sandy) )?Pentland"),
            Contact(SETH_LLOYD, "professor of mechanical engineering at MIT", match_partial=None),
            Contact(
                STEVEN_VICTOR_MD,
                "dermatologist who treated Epstein's girls",
                r"Steven? Victor( M\.?D\.?)?|Dr\.? Victor",
                link_to_bio='https://www.nytimes.com/2026/02/28/us/jeffrey-epstein-doctors.html?unlocked_article_code=1.PlA.f4B2.BgLoXD-aVKkw&smid=url-share',
                match_partial=None
            ),
            Contact('Valeria Chomsky', f"wife of {NOAM_CHOMSKY}", match_partial='both'),
            Contact(
                'Victoria Stodden',
                'professor of statistics at University of Southern California',
                link_to_bio='https://www.h-its.org/people/prof-dr-victoria-stodden/',
            ),
            Contact(YUKO_BARNABY, f"{MIT_MEDIA_LAB} Assistant to the Director", r"Y[ou]ko Ba(m|rn)(aby)?(?! Marsh)", match_partial=None),
            Contact(WHITFIELD_DIFFIE, f"MIT cryptographer and mathematician", r"whitfield.{,3}diffie?", match_partial='both'),
            organization('Dalton', 'NYC private high school where Epstein got his first job after lying about his credentials'),
            organization('iCog Labs', f'AI co. in Addis Ababa founded by {BEN_GOERTZEL} and Getnet Assefa Gesaw (funded by Epstein?)'),
            organization(
                MIT_MEDIA_LAB,
                f"once great research institute overtaken by get rich quick schemes under {JOI_ITO}",
                r"(MIT )?Media Lab",
            ),
            organization(MOUNT_SINAI, f"hospital in NYC where {EVA_DUBIN} works", r"Mount Sinai( Hospital)"),
            organization('OpenCog', f'AI research in Hong Kong overseen by {BEN_GOERTZEL} and funded in part by Epstein'),
        ],
        patterns=[
            r"Andy Lippman",  # Media Lab
            r"Arizona State University",
            r"Bard ((Early )?College|High School|Schools)",
            r"biolog(y|i(es|st))",
            r"Brotherton",
            r"Carl Sagan",
            r"chemist(ry)?",
            r"Columbia( (Business School|University))?",
            r"cryptographer",
            r"(Francis )?Crick",
            r"green card",
            r"(Karl )?Marx",
            r"(Lord )?Martin Rees",
            r"LSAT",
            r"Massachusetts Institute of Technology",
            r"Mayo Clinic",
            r"MIT",
            r"Murray Gell-Mann",
            r"NYU",
            r"New York University",
            r"Norman Finkelstein",
            r"Oxford(?! Analytica)",
            r"PhD",
            r"physics",
            r"plant biology",
            r"Praluent",
            r"Princeton( University)?",
            r"Regeneron",
            r"(Richard )?Dawkins",
            r"Rockefeller University",
            r"Sanofi",  # drug name
            r"scientist",
            r"Stanford( University)?( Hospital)?",
            r"(Ste(ph|v)en )?Hawking",
            r"(Steven? )?Pinker",
            r"Texas A&M",
            r"(?-i:TED)x?",
            r"Tulane",
            r"UCLA",
            r"Uni(versity)? of Cumbria",
            r"Wharton",
            r"Yale",
        ],
    ),
    HighlightedNames(
        label='Africa',
        style='light_pink4',
        contacts=[
            Contact('Abdoulaye Wade', f"former president of Senegal, father of {KARIM_WADE}", match_partial='first'),
            Contact('Ellen Johnson-Sirleaf', 'president of Liberia'),
            Contact('Goodluck Jonathan', 'president of Nigeria', match_partial=None),
            Contact('Ivan Glasenberg', "South African former CEO of Glencore, one of the world's largest commodity trading and mining companies"),
            Contact(
                KARIM_WADE,
                'son of the president of Senegal, arrested for corruption',
                r"Afri [xz]p?|Karim Wade",
                link_to_bio='https://www.bbc.com/news/world-africa-32020574',
                match_partial='first',
            ),
            Contact('Miles Alexander', "Operations Manager Michaelhouse Balgowan KwaZulu-Natal South Africa", match_partial=None),
            Contact('Macky Sall', "prime minister of Senegal, defeated Abdoulaye Wade", match_partial=None),
            Contact('Okey Enelamah', f"Nigerian trade minister"),
            Contact(RASSECK_BOURGI, f"{KARIM_WADE}'s lawyer", r"(Rasseck|Ute) Bourgi", match_partial='both'),
            Contact('Yoweri Museveni', 'president of Uganda', match_partial='both'),
            Contact(
                'Willis Knuckles',
                f'Liberian politician whose sex scandal Epstein, Brunel, and {SULTAN_BIN_SULAYEM} seem interested in',
                link_to_bio='https://en.wikipedia.org/wiki/Willis_Knuckles',
                match_partial=None,
            ),
            organization('Econet Wireless', 'African mobile phone company', r"Econet( Wireless)?"),
            organization('Glencore', 'Swiss mining company'),
        ],
        patterns=[
            r"Abidjan",
            r"Addis Ababa",
            r"Abuja",
            r"Angolan?",
            r"Buhari",
            r"Ethiopian?",
            r"Eritrean?",
            r"Ghana(ian)?",
            r"I[v=]ory Coast",
            r"Johannesburg",
            r"Kenyan?",
            r"Kinshasa",
            r"Liberian?",
            r"Madagascar",
            r'Malawi',
            r"Masai",
            r"Mobutu Seko",
            r"Monrovian?",
            r"Nigerian?",
            r"(Paul )?Kagame",
            r"(Republic of )?Congo",
            r"Rwandan?",
            r"Senegal(ese)?",
            r"Serengeti",
            r"Somalil?an?d?",
            r"(South )?African?",
            r"(Strive )?Masiyiwa",
            r"Sudan(ese)?",
            r"Tanzanian?",
            r"Ugandan?",
            r"Zaire",
            r"Zimbabwe(an)?",
        ],
    ),
    HighlightedNames(
        label=ARTS,
        style='wheat4',
        contacts=[
            Contact(ANDRES_SERRANO, '"Piss Christ" artist', link_to_bio='https://en.wikipedia.org/wiki/Andres_Serrano'),
            Contact('Barry Josephson', "American film producer"), #, editor FamilySecurityMatters.org"),
            Contact(BILL_SIEGEL, "documentary film producer and director", match_partial=None),
            Contact('Bobby Slayton', 'comedian and actor'),
            Contact(DAVID_BLAINE, "famous magician", link_to_bio='https://en.wikipedia.org/wiki/David_Blaine'),
            Contact('Camille Lang', "Sotheby's auction house", match_partial=None),
            Contact('Caroline Sophie', "Sotheby's auction house", match_partial=None),
            Contact('David Brenner', "American comedian and actor"),
            Contact('David Geffen', 'record label and film studio owner'),
            Contact(
                'Donna Air',
                'British actress and TV presenter',
                link_to_bio='https://graziadaily.co.uk/life/tv-and-film/donna-air/',
                match_partial=None,
            ),
            Contact('Errol Morris', 'documentary film maker, films about Robert McNamara, Donald Rumsfeld, and Bannon', match_partial=None),
            Contact(ETIENNE_BINANT, f"art advisor {QUESTION_MARKS}"),
            Contact('Frederic Fekkai', f"hairdresser Epstein liked his girls to use"),
            Contact('Larry Gagosian', 'famous art dealer', link_to_bio='https://en.wikipedia.org/wiki/Larry_Gagosian'),
            Contact('Marla Prather', f'art curator at MoMA, wife of {MORTIMER_ZUCKERMAN}'),
            Contact('Michael Ovitz', 'former president of Disney'),
            Contact('Nick Jarecki', "American filmmaker", match_partial=None),
            Contact('Richard Merkin', "painter, illustrator and arts educator"),
            Contact(STEVEN_PFEIFFER, "Associate Director at Independent Filmmaker Project (IFP)"),
            Contact('Steven Gaydos', "American screenwriter and journalist"),
            Contact('Tommy Mattolla', 'former CEO of Sony, ex-husband of Mariah Carey'),
            Contact('Val Kilmer', 'famous movie actor', match_partial=None),
            Contact(WOODY_ALLEN, f'filmmaker who married his adopted daughter {SOON_YI_PREVIN}', match_partial='first'),
            acronym('Ultimate Fighting Championship', is_emailer=True),
            organization('Phaidon', 'titan of art book publishing'),
            organization('Boom Boom Room', '"models and bottles" style club in NYC'),
        ],
        patterns=[
            r"(Art )?Spiegelman",
            r"artis(an|t)",
            r"Artspace",
            r"Ayn Rand",
            r"bono mick",
            r"Burn?ing Man",
            r"Elton John",
            r"(Frank\s)?Gehry",
            r"Harvey Weinstein", r"wientstein", r"Weinstein Co(s?|mpany)",
            r"IFP",
            r"Independent Filmmaker Project",
            r"Jagger",
            r"(Jeffrey )?Katzenberg",
            r"(Johnny )?Depp",
            r"Kid Rock",
            r"Lena Dunham",
            r"Madonna",
            r"Mariah Carey",
            r"Mark Burnett",
            r"musician",
            r"New Apostolic Church",
            r"New York Film Festival",
            r"pseudonym",
            r"Peter Getzels",
            r"Regan arts",
            r"shirley maclaine",
            r"Sotheby's",
            r"Zach Braff",
            # Video games
            r"Call of Duty",
            r"World of Warcraft",
        ],
    ),
    HighlightedNames(
        label=BILL_GATES,
        style='turquoise4',
        category=TECH_BRO,
        contacts=[
            Contact(BILL_GATES, "ex-Microsoft, Gates Foundation, bgC3"),
            Contact('Dick Henriques', 'CFO of Bill and Melinda Gates Foundation'),
            Contact(
                BORIS_NIKOLIC,
                f"biotech partner of {BILL_GATES} in bgC3 / Bill Gates Ventures, Epstein estate executor",
                r"(boris )?nikolic?",
                link_to_bio='https://www.wsj.com/articles/how-epstein-inserted-himself-in-a-split-between-bill-gates-and-a-top-gates-adviser-6d8fca69',
                match_partial='both'
            ),
        ],
        patterns=[
            r"BG",
            r"b?g?C3",
            r"(Bill ((and|or|&) Melinda )?)?Gates( Foundation)?",
            r"Kofi Rashid",
            r"Melinda( Gates)?",
            r"Microsoft",
            r"MSFT",
        ],
    ),
    HighlightedNames(
        label=BUSINESS,
        style='spring_green4',
        contacts=[
            Contact(ALIREZA_ITTIHADIEH, "CEO Freestream Aircraft Limited", r"Alireza.[Il]ttihadieh", match_partial='both'),
            Contact(BARRY_J_COHEN, emailer_pattern=r"barry ((j.?|james) )?cohen?", match_partial=None),
            Contact('Barry Zelin', 'Axiom Capital', link_to_bio='https://epsteingraph.com/people/barry-w-zelin'),
            Contact('Bob Dudley', 'CEO of BP / British Petroleum', r"[BR]ob(ert) Dudley|Dudley, Robe?r?t?"),
            Contact(DAVID_L_NEUHAUSER, f'Livermore Partners, partner of {JOSHUA_FINK}'),
            Contact('Ed Razek', "Victoria's Secret executive"),
            Contact(FILIPA_PEROVIC, f"now Filipa Fink (married to {JOSHUA_FINK}), Coatue Management"),
            Contact('Jeanne Houweling', f'CEO of Adfin, a company Epstein and {HOWARD_LUTNICK} invested in'),
            Contact(
                'Les Wexner',
                "CEO of Victoria's Secret, Abercrombie & Fitch, gave Epstein a house and power of attorney",
                r"(Les(lie)? )?Wexner",
                link_to_bio='https://en.wikipedia.org/wiki/Les_Wexner#Jeffrey_Epstein_association',
            ),
            Contact('Mitchell Baker', "founder of Mozilla", match_partial=None),
            Contact(
                NICOLE_JUNKERMANN,
                f"German countess / ex-model, NJF Capital/JunkermannGroup, investor in Revolut, gambling, China",
                r"(Nicole )?[J5]unke(nn|rm)ann?",
                link_to_bio='https://www.yahoo.com/news/articles/german-countess-advised-nhs-called-130000074.html',
            ),
            Contact('Nikolajs Smirnovs', f"{NICOLE_JUNKERMANN}'s NJF Capital / JunkermannGroup", r"Nikolajs (NJF|Smirnovs)"),
            Contact(GORDON_GETTY, "heir to oil tycoon J. Paul Getty"),
            Contact('Reza Bundy', f"founder of IronPlanet"),
            Contact(
                ROBERT_LAWRENCE_KUHN,
                "investment banker, China expert",
                r"Robert (Lawrence )?Kuhn",
                link_to_bio='https://en.wikipedia.org/wiki/Robert_Lawrence_Kuhn',
            ),
            Contact('Sam Belzberg', "Canadian businessman"),
            Contact(STEVE_WYNN, f'gambling magnate, possible dispute with {MILES_GUO}', match_partial=None),
            Contact(TOM_PRITZKER, "chairman of The Pritzker Organization and Hyatt Hotels"),
            organization('501c3', 'IRS code for a non-profit entity'),
            organization(ATT_COURT_APPEARANCE_TEAM, "AT&T", is_interesting=False),
            organization('Junkermann Group', JUNKERMANN_FUND),
            organization('Lockheed Martin', 'American military contractor'),
            organization('NJF Capital', JUNKERMANN_FUND, r"NJF( Capital)?"),
        ],
        patterns=[
            r"Arthur Klein",
            r"(Barry )?Honig",
            r"((Bill|David) )?Koch( (Bro(s|thers)|Industries))?",
            r"BP",
            r"Braintree",
            r"casino",
            r"Colony Capital",
            r"(General|Limited) Partner",
            r"Gruterite",
            r"Island Capital Group(,? LLC)?",
            r"Johann? Eliasc?h",
            r"((John|Patricia) )?Kluge",
            r"LNG",
            r"Mar[ck] Rich",
            r"McKinsey",
            r"Montilla",  # Junkermann
            r"(Mi(chael|ke) )?Ovitz",
            r"(Steve )?Wynn",
            r"Michael Klein",
            r"New Leaf Ventures",
            r"Park Partners",
            r"Robin\s?hood",
            r"Trilateral Commission",
            r"Valhi",
            r"(Yves )?Bouvier",
        ],
    ),
    HighlightedNames(
        label='cannabis',
        style='chartreuse2',
        patterns=[
            r"CBD",
            r"cann?abis",
            r"marijuana",
            r"psychedelic",
            r"THC",
            r"WEED(guide|maps)?[^s]?",
        ],
    ),
    HighlightedNames(
        label='China',
        style='bright_red',
        contacts=[
            Contact(
                'Angela Ho',
                'daughter of Chinese gambling / organized crime kingpin Stanley Ho',
                link_to_bio='https://www.theguardian.com/business/2020/may/26/stanley-ho-the-billionaire-macao-casino-tycoon-dies-aged-98',
                match_partial=None
            ),
            Contact(
                'Desmond Shum',
                f'Hong Kong financier, friend of {PETER_MANDELSON}',
                link_to_bio='https://en.wikipedia.org/wiki/Desmond_Shum',
                match_partial='both',
            ),
            Contact(
                GINO_YU,
                f"professor / game designer / AI researcher in Hong Kong, friend of {MASHA_DROKOVA}, did PR for Epstein",
                match_partial=None,
            ),
            Contact(
                MILES_GUO,
                "AKA 'Miles Kwok' AKA 'Guo Wengui', Chinese organized crime boss connected to intelligence on whose yacht Steve Bannon was arrested",
                r"Miles (Guo|Kwok)|Guo Wengui",
                link_to_bio='https://www.newyorker.com/magazine/2022/10/24/how-a-tycoon-linked-to-chinese-intelligence-became-a-darling-of-trump-republicans',
                match_partial=None,
            ),
            Contact(
                'Stanley Ho',
                'gambling magnate connected to / possible head of organized crime group',
                link_to_bio='https://www.theguardian.com/business/2020/may/26/stanley-ho-the-billionaire-macao-casino-tycoon-dies-aged-98',
                match_partial=None
            ),
            Contact('Wang Qishan', 'former vice president of China, head of China Construction Bank'),
        ],
        patterns=[
            r"Ali.?baba",
            r"Beijing",
            r"CCP",
            r"Chin(a|=|e?se)(?! Daily)",
            r'CNOOC',
            r"CNY",
            r"DPRK",
            r"Evergrande",
            r"Fang Zhi",
            r"Global Times",
            r"Guo",
            r"HK",
            r"Hong",
            r"Huaw[ae]i",
            r"Jack Ma",
            r"Kim Jong Un",
            r"Kong",
            r"Kwok",
            r"Li Botan",
            r"(Madam )?Fu Ying",
            r"Mac(au|ua)",
            r"Ministry\sof\sState\sSecurity",
            r"MSS",
            r"North .?Korean?",
            r"Peking",
            r"PRC",
            r"Pyongyang",
            r"RMB",
            r"SCMP",
            r"Shang?hai",
            r"Tianjin",
            r"V-?Nee",
            r"(?<!Article\s)Xi(aomi)?", r"Jinping",
        ],
    ),
    HighlightedNames(
        label='crime',
        style='salmon1',
        contacts=[
            Contact('John Gotti', 'boss of the Gambino crime family'),
            Contact('Anthony Trentacosta', 'Gambino crime family'),
            Contact('Michael Bilotti', 'murderer', r"Michael (A\.? )?Bilotti"),
            organization(
                'Aubin Securities',
                'Ponzi scheme run by U.S. marine Christopher Aubin',
                link_to_bio='https://www.golocalprov.com/investigations/alleged-ri-ponzi-schemers-case-expands-18-file-lawsuit-against-td-bank',
            ),
        ],
        patterns=[
            r"adderall",
            r'cocaine',
            r'(drug|mexican) (cartel|traffick(ers?|ing))',
            r'criminals?(?! defense)( prosecution)?',
            r'crime famil(ies|y)',
            r'dark web',
            r"(on )?drug(gy|s)",
            r'Gambino',
            r'heroin',
            r'khat',
            r'(meth)?amphetamine',
            r"Modafanil",
            r"narco(tic)?",
            r"murder(e[dr]|ing)?",
            r"organized crime",
            r"Provigil",
            r"(securities )?fraud(ulent)?",
            r"suicide",
            r"xanax",
        ],
    ),
    HighlightedNames(
        category=Interesting.CRYPTO,
        label=JOI_ITO,
        style='gold1',
        contacts=[
            Contact(
                JOI_ITO,
                "head of {MIT_MEDIA_LAB} and MIT Digital Currency Initiative, co-founded VC funds with Epstein",
                r"ji@media.mit.?edu|(joichi|joi)( Ito)?",
                link_to_bio='https://www.newyorker.com/news/news-desk/how-an-elite-university-research-center-concealed-its-relationship-with-jeffrey-epstein',
                match_partial='both'
            ),
            organization('Digital Garage', f"{JOI_ITO} Japanese company"),
            organization('Neoteny', f"Japanese venture fund of {JOI_ITO}"),
        ]
    ),
    HighlightedNames(
        label=Interesting.CRYPTO,
        style='orange1 bold',
        contacts=[
            Contact(
                ADAM_BACK,
                f"co-founder of {BLOCKSTREAM}, bitcoin core developer, Tether defender, currently denying Epstein connections",
                r"((Andy|Adam) )Back?",
                link_to_bio='https://www.dlnews.com/articles/people-culture/blockstream-founder-denies-relationship-with-jeffrey-epstein/',
                match_partial=None,
            ),
            Contact(
                AMIR_TAAKI,
                f"bitcoin bro, co-founder of Intersango with {DONALD_NORMAN} (and {BROCK_PIERCE}?)",
                r"Amir(?! Stemhell)( Taaki)|genjix",
                link_to_bio='https://www.axios.com/2023/12/14/customers-of-dead-bitcoin-exchange-demand-refunds',
                match_partial='last'
            ),
            Contact(
                'Andrew Larkin',
                f'insider trading charges from SEC related to online gambling, friend of {AUSTIN_HILL}',
                link_to_bio='https://www.sec.gov/enforcement-litigation/litigation-releases/lr-25422',
                match_partial=None,
            ),
            Contact(
                ANTHONY_SCARAMUCCI,
                'AKA "The Mooch", Skybridge Capital, FTX investor, Trump spokesman for two weeks',
                r"mooch|(Anthony ('The Mooch' )?)?Scaramucci",
                link_to_bio='https://fortune.com/2024/11/09/ftx-lawsuit-anthony-scaramucci-sam-bankman-fried-sbf-crypto-investments/',
            ),
            Contact(
                ARIANNA_SIMPSON,
                f"a16z crypto booster of the Axie Infinity disaster, Autonomous Partners",
                link_to_bio='https://www.bloomberg.com/news/features/2022-06-10/axie-infinity-axs-crypto-game-promised-nft-riches-gave-ruin',
                match_partial=None,
            ),
            Contact(
                AUSTIN_HILL,
                f"{BLOCKSTREAM} co-founder with {ADAM_BACK}, Brudder Ventures",
                r"Austin\s*(Hill|@blockstream.com)",
                match_partial='first'  # TODO: questionable
            ),
            Contact('Barry Silbert', f"founder of Digital Currency Group with {LARRY_SUMMERS} on the board, ZCash booster"),
            Contact(
                'Ben Horowitz',
                'co-founder of crypto heavy venture fund Andreessen Horowitz AKA a16z, Trump convert',
                link_to_bio='https://cryptadamus.substack.com/p/of-tech-bros-and-trumpers',
                match_partial=None
            ),
            Contact(
                'Blythe Masters',
                'created the weapon of financial destruction known as the Credit Default Swap, now a crypto bro-ette',
                link_to_bio='https://en.wikipedia.org/wiki/Blythe_Masters',
                match_partial=None,
            ),
            Contact(
                'Bo Collins',
                f"AKA James Robert Collins, {MERCANTILE_GLOBAL_HOLDINGS}, testified in trial of Miles Guo/Miles Kwok",
                r"(Bo|James) (Robert )?Collins",
                match_partial=None,
            ),
            Contact(
                BROCK_PIERCE,
                "Bannon partner, Tether co-founder, friend of Yair Netanyahu, sex crime history",
                r"Brock(?!man)( Pierce)?",
                # https://cryptadamus.substack.com/i/149639184/den-of-brockiquity
                link_to_bio='https://protos.com/brock-pierces-dark-and-disturbing-friendship-with-jeffrey-epstein/',
                match_partial='first',
            ),
            Contact(BRYAN_BISHOP, "executive at LedgerX and Polymath fund", match_partial=None),
            Contact('Cory Fields', 'bitcoin developer', match_partial=None),
            Contact('Dan Morehead', 'founder of Pantera Capital', r"(Dan )?Morehead"),
            Contact(
                DONALD_NORMAN,
                f"co-founder of early British crypto exchange Intersango with {AMIR_TAAKI}",
                link_to_bio='https://www.axios.com/2023/12/14/customers-of-dead-bitcoin-exchange-demand-refunds',
                match_partial=None
            ),
            Contact(ED_BOYLE, f"Medici Bank", r"Ed Boy(el|le)", match_partial=None),
            Contact('Erik Svenson', BLOCKSTREAM),
            Contact(FRANCESCA_HALL, f"'Assistant/Calendar Queen to The BlockStream team' / {AUSTIN_HILL}", match_partial=None),
            Contact('Fred Ehrsam', "co-founder of Coinbase"),
            Contact(
                GAVIN_ANDRESEN,
                'core bitcoin developer',
                r"(Gavin )?Andr.ss?en",
                link_to_bio='https://en.wikipedia.org/wiki/Gavin_Andresen',
                match_partial='both'
            ),
            Contact('Hester Peirce', f"famously pro-crypto SEC board member known as 'crypto mom'", match_partial=None),
            Contact(
                HOWARD_LUTNICK,
                "Tether's banker, Cantor Fitzgerald, Trump Secretary of Commerce",
                r"Lutnic?k(,? Howard)|How.rd( W(\.|illiam)?)? Lutnick|HWL",
                link_to_bio='https://cryptadamus.substack.com/p/trumps-transition-team-is-tethered',
            ),
            Contact(
                JEFFREY_WERNICK,
                "former COO of Parler, involved in numerous crypto companies like Bitforex",
                link_to_bio='https://www.npr.org/2021/03/23/980341703/ex-ceo-sues-parler-over-arrogant-theft-claims-site-was-hijacked',
            ),
            Contact(JEREMY_RUBIN, "bitcoin developer/researcher, cashed Epstein checks", r"Jeremy Rub(in|m)", match_partial=None),
            Contact("Jim Pallotta", f"{MIT_MEDIA_LAB} advisory board"),
            Contact("Kathryn Haun", "crypto VC at Haun Ventures, former a16z", link_to_bio='https://www.haun.co/'),
            Contact(LORENZO_DE_MEDICI, "Medici Bank, possibly Medici heir?", r"Prince Lorenzo|Lorenzo de Medici"),
            Contact(MADARS_VIRZA, f"ZCash lead dev, {MIT_MEDIA_LAB}", link_to_bio='https://z.cash/', match_partial='both'),
            Contact(
                'Marc Andreessen',
                'co-founder of crypto heavy venture fund Andreessen Horowitz AKA a16z, Trump convert',
                r"adreeson|(Marc\s*)?(?<!Gavin )Andreess?en(?!\s+Horowitz)|pmarca",
                link_to_bio='https://cryptadamus.substack.com/p/of-tech-bros-and-trumpers',
                match_partial=None,
            ),
            Contact('Matthew Gilbert', 'assistant to Howard Lutnick', match_partial=None),
            Contact("Matthew Roszak", 'co-founder of Bloq, accusations of insider trading'),
            Contact(
                'Mike Novogratz',
                'CEO of Galaxy Digital, reportedly made a billion dollars in the Terra/Luna ponzi',
                r"(Mi(chael|ke) )?Novogratz",
            ),
            Contact('Ross Ulbricht', 'founder of infamous online drug market Silk Road, pardoned by Trump'),
            Contact(
                'Steve Jurvetson',
                'board of SpaceX, former partner at Draper Fisher Jurvetson, resigned because of #MeToo allegations',
            ),
            Contact(STEVEN_SINOFSKY, "a16z, ex-Microsoft, loves bitcoin", r"Steven Sinofsky?"),
            Contact('Suhas Daftuar', 'Chaincode Labs'),
            Contact(
                'Tim Draper',
                'partner at Draper Fisher Jurvetson, loves bitcoin',
                r"Tim(othy)?( Cook)? Draper",
                link_to_bio='https://x.com/Cryptadamist/status/2027175564444930286',
            ),
            Contact('W. Bradford Stephens', f"co-founder of {BLOCKCHAIN_CAPITAL}", r"(Brad(ford)?|Bart) Stephens", match_partial=None),
            Contact('William Wheeler', f'co-founder of cashintocoins.com, {EXPRESSCOIN} with {BROCK_PIERCE}', match_partial=None),
            Contact("Wladimir van der Laan", 'bitcoin core developer', r"Wladimir( van der Laan)?"),
            organization(
                'a16z',
                "AKA 'Andressen Horowitz', crypto heavy venture fund of Marc Andreessen / Ben Horowitz, invested in many scams",
                r"a16z|Andrees?sen Horowitz|andresson",
                link_to_bio='https://cryptadamus.substack.com/p/of-tech-bros-and-trumpers',
            ),
            organization('Alphabit', 'crypto fund'),
            organization('BGC', f"{CANTOR} related firm of {HOWARD_LUTNICK}", r"BGC( (International|Partners))?"),
            organization('Bioptix', 'old name of RIOT Blockchain from when it was a biotech company'),
            organization('Bitfinex', f"crypto exchange run by the same people that run Tether"),
            organization('BitFury', 'Dutch bitcoin mining company founded by Valery Vavilov and Mark Dollar'),
            organization('Bitmain', f"Chinese manufacturer of bitcoin mining rigs"),
            organization(BLOCKSTREAM, f"early crypto firm co-founded by {ADAM_BACK} and {AUSTIN_HILL}", r"(the)?blockstream"),
            organization(
                BLOCKCHAIN_CAPITAL,
                f"early crypto VC fund co-founded by Bart Stephens and {BROCK_PIERCE}, invested in by Epstein",
                link_to_bio='https://protos.com/the-context-159-%e2%81%89%ef%b8%8f-epstein-a-convicted-pedo-invested-in-coinbase/',
            ),
            organization('Bloq', 'blockchain company', is_interesting=False),
            organization(
                'BTC-e',
                'infamous Russian crypto exchange through which Mt. Gox stolen funds were laundered, CEO Vinnik convicted but pardoned by Trump',
                link_to_bio='https://en.wikipedia.org/wiki/BTC-e',
            ),
            organization(
                CANTOR,
                f"Howard Lutnick's financial firm",
                r"Cantor(,? (Fitzgerald|Opportunities|Ventures?))?",
                link_to_bio='https://cryptadamus.substack.com/p/trumps-transition-team-is-tethered',
            ),
            organization(
                'Coinbase',
                'largest American crypto exchange, early investment from Epstein',
                link_to_bio='https://protos.com/the-context-159-%e2%81%89%ef%b8%8f-epstein-a-convicted-pedo-invested-in-coinbase/',
            ),
            organization(
                'Cryptocurrency Partners',
                f'crypto fund set up by Epstein and {BROCK_PIERCE} as a sidecar to {BLOCKCHAIN_CAPITAL}',
                r"Crypto ?Currency Partners( II)?",
                link_to_bio='https://protos.com/brock-pierces-dark-and-disturbing-friendship-with-jeffrey-epstein/',
            ),
            organization(
                'Crypto PR Lab',
                f"PR firm founded by {MARIA_PRUSAKOVA} and {ALEKSANDRA_KARPOVA}, advised by Epstein",
                link_to_bio='https://x.com/CryptoPRLab',
            ),
            organization(
                'Digital Currency Initiative',
                f"crypto part of {MIT_MEDIA_LAB}",
                r"Digital (Assets?|Currenc(ies|y)) Initiative",
                link_to_bio='https://www.dci.mit.edu/',
            ),
            organization(
                'Digital Currency Group',
                'AKA "DCG", formerly the most import crypto VC fund in the US, rekt in FTXplosion',
                r"DCG|Digital Currency Group",
                link_to_bio='https://www.cnbc.com/2025/01/17/crypto-firm-dcg-to-pay-sec-38point5-million-for-misleading-investors.html',
            ),
            organization(
                'Draper Fisher Jurvetson',
                f"fund run by Tim Draper, John Fisher, and Steve Jurvetson, blackmail allegations",
                r"DFJ( Capital|Fund)?|Draper Fisher Jurvetson",
                link_to_bio='https://www.psychedelicamericas.org/p/fbi-memo-links-venture-capitalist-and-psychedelic-investor-steve-jurvetson-to-epstein-connected-netw',
            ),
            organization('Electric Coin Company', f"FKA 'Zerocoin', {MADARS_VIRZA} and untraceable cryptocurrency ZCash"),
            organization(EXPRESSCOIN, f"bitcoin market founded by {BROCK_PIERCE} and William Wheeler"),
            organization('Intersango', 'early UK bitcoin exchange'),
            organization(
                'Kraken',
                '2nd largest American crypto exchange, CEO + employees prone to calling the US dollar "slave money"',
                link_to_bio='https://www.bakerlaw.com/insights/kraken-loses-bid-to-avoid-turning-over-customer-information-to-irs/',
            ),
            organization(
                KYARA_INVESTMENT,
                f"Epstein crypto fund, all but one created jointly with {JOI_ITO}",
                r"Kyara( Investments?)?( [IV]+)?",
            ),
            organization('LedgerX', 'crypto derivatives platform acquired by FTX for $298 million in a very shady deal'),
            organization(
                'Libra',
                f"Facebook's attempt at a stablecoin that was canceled by the US government",
                link_to_bio='https://www.amazon.com/Libra-Shrugged-Facebook-Tried-Money-ebook/dp/B08KK9SZP6',
            ),
            organization(
                'Medici Bank',
                f"crypto friendly bank set up by {LORENZO_DE_MEDICI} with investment from {MARIA_PRUSAKOVA} and maybe {BROCK_PIERCE}",
            ),
            organization(
                MERCANTILE_GLOBAL_HOLDINGS,
                'company of Bo Collins who ended up testifying in trial of chinese criminal Miles Guo / Miles Kwok',
            ),
            organization('Mindshift', f"conference on Epstein's island organized by {AL_SECKEL}", r"Mindshift( conference)?"),
            organization(
                'Mt. Gox',
                f"FKA 'Magic the Gathering: Online Exchange', infamous early bitcoin market that was hacked / robbed",
                r"Mt\.? Gox",
                link_to_bio='https://en.wikipedia.org/wiki/Mt._Gox',
            ),
            organization(
                'Noble Bank',
                f"failed crypto friendly bank with ties to Tether and {BROCK_PIERCE}",
                r"Noble (Bank|Markets)",
                link_to_bio='https://news.bitcoinprotocol.org/how-noble-markets-connected-tether-epstein-and-their-shadow-banking-network/',
            ),
            organization('OneCoin', 'massive $10 billion crypto + multi-level marketing fraud created by Ruja Ignatova'),
            organization('Pantera Capital', "silicon valley crypto fund of Dan Morehead"),
            organization('Parabridge International Services', f'entity associated with {CANTOR}'),
            organization('PayPay', 'bitcoin debit card', r"PayPay( Card)?"),
            organization('Polymarket', 'blockchain based gambling site ("prediction market")'),
            organization('Ribbit Capital', 'crypto friendly venture fund'),
            organization('Ripple', 'token issuing company run by Trump megadonor Brad Garlinghouse'),
            organization('Silk Road', f'online illegal drugs market run by Ross Ulbricht, first real use case for crypto'),
            organization('Stellar', 'blockchain architecture alternative to bitcoin and ethereum', r"stellar\.org"),
            organization(
                'Tether',
                f"$180 billion stablecoin founded by {BROCK_PIERCE}, beloved by drug cartel + rogue nuclear states, cash managed by {HOWARD_LUTNICK}",
                link_to_bio='https://cryptadamus.substack.com/p/trumps-transition-team-is-tethered'
            ),
            organization(
                'Zerocoin',
                f"early name for Epstein funded untraceable cryptocurrency ZCash developed by {MADARS_VIRZA}",
                r"ZeroC(ash|oin)",
                link_to_bio='https://z.cash/',
            ),
        ],
        patterns=[
            r"altern?ative (currenc(ies|y)|money)",
            r"Balaji( Srinivisan)?",
            r"Ben Forman",
            r"bit[o\s]?coin( Foundation)?",
            r"Bit(Angels|Fury|Go)",
            r"block (chain|tree)",
            r"Brac",  # Brock? EFTA01792443
            r"Bradley Rotter",
            r"Brian Forde",
            r"Brudder( Ventures)?",
            r"CF(G)",
            r"Chaincode",
            r"coins?( Center)?",
            r"complementary currency",
            r"Coinmint",
            r"cr[iy]?pto (coins?|currenc(y|ies)|mining)?",
            r"crypto(graph(ic|y))?",
            r"digital (assets?|currenc(ies|y))",
            r"e-?(currency|gold)",
            r"ethereum",
            r"FTX",
            r"(?-i:G)alaxy",
            r"Genghis Coin",
            r"GogoCoin",
            r"ICO",
            r"itBit",
            r"Joyce Kim",
            r"Layer (1|One)",
            r"Linden Dollar",
            r"Li(gh)?te?coin",
            r"Northern Data",
            r"(Patrick )?Murck",
            r"Playsino",
            r"(?-i:R)IOT( Blockchain)?",  # (?-i:) makes it case sensitive
            r"Ron Rivest",
            r"Silk Road",
            r"SpanCash",
            r"stable coin",
            r"(?-i:S)tellar",
            r"Stephens Inv(\.|estment) M(anagement|gmt\.?)",
            r"Steve Waterhouse",
            r"supersecretbitcoinproject",
            r"Tally Capital",
            r"(transparent|virtual) (currenc(ies|y)|good|item|money)",
            r"wash trad(es?|ing)",
            r"Wire ca\n?rd",
            r"XRP",
            r"Z Cash",
            r"ZECC?",
            r"(zero knowledge |zk)pro(of|tocols?)",
        ],
    ),
    HighlightedNames(
        label='deepak',
        style='dark_sea_green4',
        contacts=[
            Contact(CAROLYN_RANGEL, f"{DEEPAK_CHOPRA}'s assistant {'(???)'}"),
            Contact(DEEPAK_CHOPRA, "woo woo")
        ],
    ),
    HighlightedNames(
        label='Democrat',
        style='sky_blue1',
        contacts=[
            Contact('Alex Mayorkas', 'future DHS secretary', r"Al(i|ex) Mayorkas"),
            Contact('Andrew Cuomo', 'governor of New York'),
            Contact(
                BILL_RICHARDSON,
                'former governor of New Mexico',
                r"(Governor )?(Bill )?Richardson",
                link_to_bio='https://en.wikipedia.org/wiki/Bill_Richardson',
            ),
            Contact('Ed Mezvinsky', 'former congressman, criminal Ponzi schemer', r"(Ed(ward)? )?Mezvinsky",),
            Contact('Eliot Spitzer', 'former prosecutor / NY governor who went after big banks, prostitution scandal', r"(Eliott? )?Spitzer(, Eliot)?"),
            Contact('George Mitchell', 'former US senator from Maine', match_partial=None),
            Contact(
                'Greg Craig',
                'former Obama White House counsel, worked w/Paul Manafort in Ukraine, acquitted of charges',
                link_to_bio='https://www.politico.com/story/2019/05/13/rick-gates-roger-stone-greg-craig-1318870',
                match_partial=None,
            ),
            Contact('Janis Hartley', f'assistant to Governor Bill Richardson {QUESTION_MARKS}', match_partial=None),
            Contact(PAUL_PROSPERI, "friend of Bill Clinton"),
        ],
        patterns=[
            r"(Al )?Franken",
            r"Al Gore",
            r"((Barac?k|President) )?Obama",
            r"((Bill|Hillart?y) )?Clinton",
            r"((Chuck|Charles) )?S(ch|hc)umer",
            r"Chelsea Clinton",
            r"Debbie Wasserman Schultz",
            r"Dem(ocrat(ic)?)?",
            r"(Diana )?DeGette",
            r"DNC",
            r"Elena Kagan",
            r"Eric Holder",
            r"(George )?Soros",
            r"Hakeem Jeffries",
            r"Hill?ary",
            r"HRC",
            r"(Jo(e|seph) )?Biden",
            r"(John )?Kerry",
            r"Lisa Monaco",
            r"(Matteo )?Salvini",
            r"Maxine Waters",
            r"(Nancy )?Pelosi",
            r"Occupy New York",
            r"Open Society( Global Board)?",
            r"Ron Dellums",
            r"Schumer",
            r"(Tim(othy)? )?Geithner",
            r"Tom McMillen",
            r"Vernon Jordan",
        ],
    ),
    HighlightedNames(
        label='Dubins',
        style='medium_orchid1',
        contacts=[
            Contact(EVA_DUBIN, f"Epstein's ex-girlfriend now married to {GLENN_DUBIN}, doctor at {MOUNT_SINAI}", match_partial=None),
            Contact(GLENN_DUBIN, "Highbridge Capital Management, married to Epstein's ex-gf Eva", match_partial='first'),
        ],
        patterns=[r"((Celina|Eva( Anderss?on)?|Glenn?) )?Dubin"],
    ),
    HighlightedNames(
        label='employee',
        style='light_slate_blue',
        contacts=[
            Contact('Adriana Ross', 'named co-conspirator', match_partial=None),
            Contact('Alfredo Rodriguez', "Epstein's butler, stole Epstein's black book", match_partial=None),
            Contact(BELLA_KLEIN, "one of Epstein's accountants", match_partial=None),
            Contact('Bernard Kruger', "Epstein's doctor", match_partial=None),
            Contact('Brice Gordon', 'property manager', match_partial=None),
            Contact(CECILIA_STEEN, f'Epstein assistant, moved to Dubai to work for money launderers (?)'),
            Contact(DAPHNE_WALLACE, "LSJE accountant", r"Da.hne Wallace", match_partial=None),
            Contact(DAVID_RODGERS, "Epstein's pilot", match_partial=None),
            Contact(EDUARDO_ROBLES, "home builder at Creative Kingdom Dubai", r"Ed(uardo)? Robles", match_partial=None),
            Contact(ERIC_ROTH, "jet decorator at International Jet", match_partial=None),
            Contact(GWENDOLYN_BECK, "Epstein fund manager in the 90s, ran for Congress", match_partial='first'),
            Contact('Harry Beller', "one of Epstein's accountants"),
            Contact('Ike Groff', f"maybe brother or husband of {LESLEY_GROFF}?", is_organization=True, match_partial=None),
            Contact(JANUSZ_BANASIAK, "Epstein's house manager", r"Janu[is]z Banasiak", match_partial='both'),
            Contact('John Allessi', "Epstein's houseman"),
            Contact(JEAN_HUGUEN, "interior design at Alberto Pinto Cabinet", r"Jean[\s.]Huguen"),
            Contact('Jennaine Ruan', f'IT Manager at {SOUTHERN_TRUST_COMPANY}', r"Je(nn|rm)aine Ruan"),
            Contact(JOJO_FONTANILLA, "Filipino housekeeper", r"Jo.. Fontanilla"),
            Contact('Lalasa', f'house cleaner {QUESTION_MARKS}'),
            Contact('Larry E. Morrison', "Epstein's pilot", match_partial=None),
            Contact(LAWRANCE_VISOSKI, "Epstein's pilot", r"La(rry|wrance) Visoski?|Lvjet"),
            Contact(LESLEY_GROFF, "unindicted co-conspirator, assistant who managed Epstein's calendar", r"Lesl(ey|ie) (K(\.|atherine)? )?Gro(ff)?"),
            Contact('Linda Pinto', "interior design at Alberto Pinto Cabinet"),
            Contact(LYN_FONTANILLA, "Filipino housekeeper", r"L.nn? Fontanilla"),
            Contact(MERWIN_DELA_CRUZ, "housekeeper", r"Merwin"),
            Contact(
                'Myla Trestiza',
                'yacht staff',
                link_to_bio='https://thespinoff.co.nz/society/05-02-2026/the-epstein-files-and-nz-managers-models-and-the-kiwi-billionaire',
            ),
            Contact(
                NADIA_MARCINKO,
                'Lolita Express pilot, FKA Nadia Marcinkova',
                r"Na[dď]i?a Marcinko(v[aá])?|nadja2102[@e]yahoo(\.?com)",
                link_to_bio='https://archive.ph/Qa6vU',  # https://www.nybooks.com/articles/2026/03/26/the-devil-himself-jeffrey-epstein-enright/
            ),
            Contact('Perry Lang', f"Epstein's personal chef 1998-2002", r"(Adam )?Perry Lang"),
            Contact('Richard Barnett', "logistics for Epstein's properties", r"Rich(ard)? Barnett", match_partial=None),
            Contact('Sarah Kellen', "now Sarah Vickers, named co-conspirator", r"(Sarah )?(Kellen|Vickers)"),
            Contact('Sean J. Lancaster', "airplane reseller"),
            Contact('Steve Griffis', 'AKA "Steve from downstairs", building employee', r"Steve (Griffis|\(from downstairs)"),
            Contact(STORY_COWLES, "Epstein's male assistant"),
            Contact('Una Pascal', f"{SOUTHERN_TRUST_COMPANY} accountant", match_partial=None),
            Contact('Valdson Vieira Cotrin', f"Paris driver, annual trip to Brasil", r"(Cotrin )?Valdson( Contrin)?", match_partial='both'),
            Contact('William Murphy', f"sysadmin at {RICHARD_KAHN}'s HBRK, did tech stuff for Epstein and Epstein used his name on Skype", match_partial=None),
        ],
    ),
    HighlightedNames(
        label=JEE,
        style=EPSTEIN_COLOR,
        contacts=[
            Contact(
                name=JEFFREY_EPSTEIN,
                emailer_pattern=r"j?ee[vy]acatio[mn]?[©@baeoq]?g?(mail.com)?|Epstine|\bJEE?\b|Jefff?(rey)? (Edward )?E((sp|ps)tein?)?( VI Foundation)?|jeeproject@yahoo.com|J Jep|Jeffery Edwards?|(?<!(ark L.|rd Jay|Edward) )Epstein(,? Jeffrey( Edward)?)?|Jeffrey Epst.*comj?|littlestjeff@yahoo|zorroranch@aol",
                match_partial=None,
            ),
            Contact(MARK_EPSTEIN, "brother of Jeffrey", r"Mark (L\.? )?(Epstein|Lloyd)", match_partial=None),
        ]
    ),
    HighlightedNames(
        label='Epstein',
        style=EPSTEIN_COLOR,
        contacts=[
            Contact('sultan175', f"Epstein's account name on Match.com", is_emailer=False),
            organization(
                f"{ASIA_GATEWAY} Limited",
                f"corporate vehicle set up by Epstein and {DAVID_STERN}, presumably to manage money of wealthy Chinese",
                r"Asia\s*Gateway(\s*L(imited|td))?",
            ),
            epstein_co('FT Real Estate'),
            epstein_co('Harlequin Dane LLC'),
            epstein_co('Island Grounds Inc.'),
            epstein_co('Hyperion Air', r"Hyperion( Air)?"),
            epstein_co('Jeepers Inc.'),
            # epstein_co('JEGE LLC'),
            epstein_co('JEGE, Inc.'),
            epstein_co('Laurel Inc.'),
            epstein_co('LSJ LLC'),
            epstein_co('LSJE, LLC'),
            epstein_co('Laurel, Inc.'),
            epstein_co('Liquid Funding', link_to_bio='https://craigunger.substack.com/p/jeffrey-epsteins-really-big-short'),
            epstein_co('Nautilus'),
            epstein_co('Neptune, LLC'),
            epstein_co('NES LLC'),
            epstein_co('New York Strategy Group'),
            epstein_co('Plan D'),
            epstein_co('Prytanee, LLC'),
            epstein_co('SCI JEP'),
            epstein_co('Southern Country International'),
            epstein_co('Thomas World Air'),
            epstein_co('Zorro Management'),
            epstein_co('Zorro Development Corp'),
            epstein_trust('2007'),
            epstein_trust('2012', trustees=[ANDREW_FARKAS, DARREN_INDYKE, JES_STALEY]),
            epstein_trust('2014', trustees=[DARREN_INDYKE, DAVID_MITCHELL, JES_STALEY]),
            epstein_trust('2017', trustees=[DARREN_INDYKE, EVA_DUBIN, RICHARD_KAHN]),
            epstein_trust('2018', trustees=[DARREN_INDYKE, EVA_DUBIN, KATHRYN_RUEMMLER]),
            epstein_trust('Butterfly Trust', beneficiaries=[KARYNA_SHULIAK]),
            epstein_trust('Caterpillar Trust', r"(2017 )?Caterpillar Trust"),
            epstein_trust('C.O.U.Q. Foundation', r"C\.?O\.?U\.?Q\.?( Foundation)?"),  # charity account
            epstein_trust('Enhanced Education'),
            epstein_trust('Financial Trust Company', r"Financial Trust Co(\.|mpany)"),
            epstein_trust('Gratitude America'),
            epstein_trust('Haze Trust'),
            epstein_trust('Southern Financial Company', r"Southern Financial( (Co(mpany)?|LLC))?"),
            epstein_trust('Southern Trust'),
            epstein_trust('The 1953 Trust', beneficiaries=[DARREN_INDYKE, RICHARD_KAHN]),
            epstein_trust('The Sweater Trust', r"(The )?Sweater Trust"),
            organization('Little Saint James Island', r'Little S(ain)?t\.? James( Island)?'),
            organization('Mort, Inc.', 'Epstein company', r"Mort,? Inc\.?"),
        ],
        patterns=[
            r"(?-i:The Prof)",
            r"Zorro( Ranch)?",
        ],
    ),
    HighlightedNames(
        label=LAWYER,  # Epstein's lawyers
        style='purple',
        contacts=[
            Contact(ALAN_DLUGASH, 'tax partner at Paneth and Shrone', r"Alan (J.? )?Dlugash"),
            Contact('Alan S Halperin', "partner at Paul, Weiss"),
            Contact(ALAN_DERSHOWITZ, f"{HARVARD} Law School professor", r"(alan.{1,7})?dershowi(lz?|t?z)|AlanDersh"),
            Contact(ARDA_BESKARDES, "NYC immigration attorney allegedly involved in sex-trafficking operations"),
            Contact('Bebe Avdiu', f'legal assistant to {DARREN_INDYKE}'),
            Contact(
                BENNET_MOSKOWITZ,
                "represented the Epstein estate executors",
                r"Moskowitz.*Bennet|Bennet.*Moskowitz",
                match_partial=None,
            ),
            Contact(BRAD_KARP, "head of the law firm Paul Weiss", r"Brad (S.? )?Karp|Karp, Brad", match_partial=None),
            Contact('Connie Zaguirre', f"office of {'Robert D. Critton Jr.'}"),
            Contact('Daniel Weiner', f"lawyer for Epstein executors {DARREN_INDYKE} & {RICHARD_KAHN}", match_partial=None),
            Contact(DAVID_SCHOEN, "Epstein criminal defense attorney after 2019 arrest"),
            Contact(DEBBIE_FEIN, f"Epstein {EPSTEIN_V_ROTHSTEIN_EDWARDS_ATTORNEY}"),
            Contact('Erika Kellerhals', "attorney in St. Thomas"),
            Contact(FRED_HADDAD, "co-founder of Heck's in West Virginia", match_partial=None),
            Contact(GERALD_LEFCOURT, f"friend of {ALAN_DERSHOWITZ}", r"Gerald (B\.? )?Lefcourt"),
            Contact('Howard Rubenstein', "Epstein's former spokesman"),
            Contact(JACK_GOLDBERGER, CRIMINAL_DEFENSE_2008, r"Jack( A(lan|\.?))?Goldberger"),
            Contact(JACKIE_PERCZEK, CRIMINAL_DEFENSE_2008, r"jackie percze[kl]?"),
            Contact(JAY_LEFKOWITZ, f"Kirkland & Ellis partner, {CRIMINAL_DEFENSE_2008}"),
            Contact(JESSICA_CADWELL, f"paralegal to {ROBERT_D_CRITTON_JR} whom Epstein appears to recruit"),
            Contact(
                KEN_STARR,
                "head of the Monica Lewinsky investigation into Bill Clinton",
                r"starr, ken|Ken(neth (W. )?)? starr?|starr",
                link_to_bio='https://en.wikipedia.org/wiki/Ken_Starr',
            ),
            Contact(LILLY_SANCHEZ, CRIMINAL_DEFENSE_ATTORNEY, r"Lilly.{,15}Sanchez"),
            Contact(MARTIN_WEINBERG, CRIMINAL_DEFENSE_ATTORNEY, r"Martin.{,15}Weinberg"),
            Contact('Michael J. Pike', 'Epstein lawyer', match_partial=None),
            Contact(MICHAEL_MILLER, "Steptoe LLP partner", r"Micha(el)? Miller|Miller, Micha(el)?", match_partial=None),
            Contact(REID_WEINGARTEN, "Steptoe LLP partner", r"Weingarten, Rei[cdi]|Rei[cdi] Weingarten"),
            Contact(ROBERT_D_CRITTON_JR, CRIMINAL_DEFENSE_ATTORNEY, r"Robert D.? Critton,? Jr\.?", match_partial=None),
            Contact('Robert Gold', "helped Epstein track down money belonging to Spanish families", match_partial=None),
            Contact('Roy Black', CRIMINAL_DEFENSE_2008, match_partial=None),
            Contact(SCOTT_J_LINK, CRIMINAL_DEFENSE_ATTORNEY, match_partial=None),
            Contact(STACEY_RICHMAN, f"New York {CRIMINAL_DEFENSE_ATTORNEY}", r"srichmanlaw|Stacey Richman"),
            Contact(
                'Stephanie Thacker',
                "West Virginia attorney who defended Epstein, now a federal judge",
                link_to_bio='https://www.wboy.com/news/west-virginia/where-is-west-virginia-mentioned-in-the-epstein-files/',
            ),
            Contact(
                TONJA_HADDAD_COLEMAN,
                f"civil attorney Epstein v. Scott Rothstein, {BRAD_EDWARDS}, & L.M.",
                r"To(nj|rl)a Haddad Coleman|haddadfm@aol.com",
                match_partial='first',
            )
        ],
        patterns=[
            r"dersh",
            r"Kate Kelly",
            r"Kirkland & Ellis",
            PERKINS_COIE,
            r"Steptoe( & Johnson)?( LLP)?",
        ],
    ),
    HighlightedNames(
        label='law firm',  # Non-Epstein affiliated
        style='medium_purple3',
        contacts=[
            organization(CLIFFORD_CHANCE, f'law firm where {MARIA_PRUSAKOVA} did an internship in Paris'),
            organization('Latham & Watkins', f'law firm where {KATHRYN_RUEMMLER} worked', r"Latham (&|and) Watkins"),
        ],
        patterns=[
            r"(Leon )?Jaworski",
            r"Paul,? Weiss",
            r"Skadden(,? Arps)",
            r"Sull(ivan)? (&|and)? Crom(well)?",
        ]
    ),
    HighlightedNames(
        label=ESTATE_EXECUTOR,
        style='purple3 bold',
        category=LAWYER,
        contacts=[
            Contact(
                DARREN_INDYKE,
                "Epstein's lawyer and estate executor",
                r"darren$|Darren (K(\.|eith)? )?[il]n[dq]_?yke?|dkiesq",
                link_to_bio='https://en.wikipedia.org/wiki/Estate_of_Jeffrey_Epstein',
            ),
            Contact(EMAD_HANNA, f"Project controller for {RICHARD_KAHN}'s HBRK Associates", match_partial=None),
            Contact(HENRY_JARECKI, 'psychiatrist and philanthropist, owned neighboring island', match_partial=None),
            Contact(
                RICHARD_KAHN,
                "Epstein's accountant and estate executor",
                r"rich(ard)? kahn?",
                link_to_bio='https://en.wikipedia.org/wiki/Estate_of_Jeffrey_Epstein',
            ),
        ],
        patterns=[
            r"HBRK( (Associates,? )?Inc)?",
        ]
    ),
    HighlightedNames(
        label='Europe',
        style='light_sky_blue3',
        contacts=[
            Contact('Alastair Campbell', 'journalist, spokesman for Tony Blair', match_partial='first'),
            Contact('Alistair Darling', 'former UK Chancellor of the Exchequer under Gordon Brown'),
            Contact(ANDRZEJ_DUDA, "former president of Poland"),
            Contact(
                BARBRO_C_EHNBOM,
                "Swedish pharmaceuticals, SALSS, alleged recruiter of girls",
                r"behnbom@aol.com|(Barbro\s.*)?Ehnbom|Barbro",
                link_to_bio='https://www.reddit.com/r/TrueAnon/comments/1pn8pdj/episode_509_jeffreys_bbb/'
            ),
            Contact(
                'Benjamin Wegg-Prosser',
                f"CEO of {PETER_MANDELSON}'s failed lobbying firm Global Counsel",
                link_to_bio='https://en.wikipedia.org/wiki/Benjamin_Wegg-Prosser',
            ),
            Contact('Caroline Lang', "daughter of Jack Lang"),
            Contact(EDWARD_ROD_LARSEN, f"son of {TERJE_ROD_LARSEN}", match_partial=None),
            Contact('Fabrice Aidan', f"diplomat who worked with {TERJE_ROD_LARSEN}"),
            Contact('Jack Lang', "former French Minister of National Education", match_partial=None),
            Contact(
                'Martine Vik Magnussen',
                f'murdered by son of {SHAHER_ABDULHAK_BESHER}',
                link_to_bio='https://en.wikipedia.org/wiki/Murder_of_Martine_Vik_Magnussen',
                match_partial=None
            ),
            Contact(
                MIROSLAV_LAJCAK,
                f"Russia-friendly Slovakian national security advisor, friend of {STEVE_BANNON}",
                r"Miro(slav)?( Laj[cč][aá]k)?",
                link_to_bio='https://www.bbc.com/news/articles/cnvgljj1dygo',
            ),
            Contact('Oleksandra Okasha', 'Ukrainian travel agent (?)', r"Okasha, Oleksandra"),
            Contact('Oleksandr Vilkul', f"former deputy prime minister of Ukraine"),
            Contact(
                PETER_MANDELSON,
                "recently arrested former UK ambassador to the US",
                r"((Lord|Peter) )?M[ae]ndelson",
                link_to_bio='https://bylinetimes.com/2026/02/05/peter-mandelsons-downfall-puts-morgan-mcsweeneys-future-in-doubt/',
            ),
            Contact('Sarah Ferguson', f'AKA "Fergie", former Duchess of York / wife of {PRINCE_ANDREW}', match_partial=None),
            Contact(
                TERJE_ROD_LARSEN,
                f"Norwegian head of {INTERNATIONAL_PEACE_INSTITUTE} (IPI), gave jobs to Epstein's eastern European girls",
                r"Terje(( (R[øo]e?d[-\s])?)?Lars[eo]n)?",
                link_to_bio='https://apnews.com/article/jeffrey-epstein-kevin-rudd-oslo-crime-think-tanks-ca62b1c799d2cb3bb346afcf4dfec355',
            ),
            Contact(
                THORBJORN_JAGLAND,
                "former prime minister of Norway, Nobel Peace Prize Committee, indicted",
                r"(Thor.{3,8})?Jag[il]and?",
                link_to_bio='https://www.bbc.com/news/articles/c5yqr8eggvwo',
            ),
            Contact('Viktor Yushchenko', 'former president of Ukraine'),
            Contact('Viktor Orban', 'prime minister of Hungary', r"(Vi(c|k)tor )?Orbah?n"),
            acronym('European Central Bank'),
            acronym(
                INTERNATIONAL_PEACE_INSTITUTE,
                "gave jobs to Epstein's girls",
                link_to_bio='https://apnews.com/article/jeffrey-epstein-kevin-rudd-oslo-crime-think-tanks-ca62b1c799d2cb3bb346afcf4dfec355',
            ),
            organization('AfD', 'right wing German political party'),
            organization('Global Counsel', f"failed strategic consultancy / lobbying firm of {PETER_MANDELSON}"),
            organization(
                'Swedish American Life Science Summit',
                f"(SALSS) {BARBRO_C_EHNBOM} event, recruiting grounds for Epstein",
                r"Swedish American Life Science Summit|SALSS",
                link_to_bio='https://www.politico.eu/article/jeffrey-epstein-files-sweden-business-leader-ehnbom-proposed-meet-women/',
            ),
            organization('Zug', "city in Switzerland known as a hub for crypto and dodgy finance"),
        ],
        patterns=[
            r"Aegean( Sea)?",
            r"Amsterdam",
            r"(Angela )?Merk(el|le)",
            r"Austrian?",
            r"Barcelona",
            r"Belgi(an|um)",
            r"(Benjamin )?Harnwell",
            r"Berlin",
            r"Borge",
            r"Boris Johnson",
            r"Bosnian?",
            r"Brexit(eers?)?",
            r"Brit(ain|ish)",
            r"Brussels",
            r"Buckingham Palace",
            r"Bulgarian?",
            r"Canadi?an?",
            r"Cannes",
            r"Capri",
            r'Courchevel',
            r"Croatian?",
            r"Cypr(iot|us)",
            r"David Cameron",
            r"Davos",
            r"Dutch",
            r"England",
            r"Estonian?",
            r"EU",
            r"Europe(an)?( Union)?",
            r"Finland",
            r'Florence',
            r"Fr(ance|ench)",
            r"Geneva",
            r"Germany?",
            r"Gibralt[ae]r",
            r"Gillard",
            r"Gree(ce|k)",
            r"Hollande",
            r"Hungar(ian|y)",
            r"Ibizan?",
            r"Iceland(ic)?",
            r"Ital(ian|y)",
            r"Jacques",
            r"(Justin )?Trudeau",
            r"Kiev",
            r"Latvian?",
            r"Lie?chtenstein",
            r"Lisbon",
            r"Lithuanian?",
            r"Le Pen",
            r"(?<!DOJ\s)London",
            r"Luxembourg",
            r"Macron",
            r"Malta",
            r"Mediterranean",
            r"Melusine",
            r"MI 5",
            r"Milano?",
            r"Monaco",
            r"Muenchen",
            r"Munich",
            r"Nap(les|oli)",
            r"NATO",
            r"(Nicholas )?Sarkozy",
            r"Nigel( Farage)?",
            r"(Northern )?Ireland",
            r"Norw(ay|egian)",
            r"Odessa",
            r"Oslo",
            r"Paris(ian)?",
            r"Pol(and|ish)",
            r"pope",
            r"Portug(al|uese)",
            r"Prague",
            r"Riga",
            r"Rotterdam",
            r"San Marino",
            r"Schengen( (Area|Visa))?",
            r"Scotland",
            r"(Sebastian )?Kurz",
            r"Slov(ak|en)ian?",
            r"Spa(in|ni(ard|sh))",
            r"Stockholm",
            r"Strasbourg",
            r"Strauss[-\s]?Kahn",
            r"Swed(en|ish)(?![-\s]+American Life Scienc)",
            r"Swi(ss|tzerland)",
            r"Tommy Robinson",
            r"(Tony )Blair",
            r"United Kingdom",
            r"U\.K\.",
            r"Ukrai?n(e|ian)",
            r"Vatican( City)?",
            r"Venice",
            r"Venetian",
            r"Vienn(a|ese)",
            r"Zurich",
        ],
    ),
    HighlightedNames(
        label=Neutral.FINANCE,
        style='green',
        contacts=[
            Contact(AMANDA_ENS, "Citigroup", r"ens, amanda?|Amanda.Ens", match_partial=None),
            Contact(
                'Ari Glass',
                f'Boothbay manager whom Epstein called "a bit sketchy" but invested $50 million with',
                match_partial=None,
            ),
            Contact('Ben Bram', 'Watermill Trading'),
            Contact(
                BRAD_WECHSLER,
                f"IMAX chairman, head of {LEON_BLACK}'s personal investment vehicle",
                link_to_bio='https://www.cnn.com/2026/02/21/business/apollo-epstein-wall-street',
            ),
            Contact(DANIEL_SABBA, f"{UBS} Investment Bank"),
            Contact(
                name=DAVID_FISZEL,
                info="CIO Honeycomb Asset Management, Epstein invested in Spotify through him",
                emailer_pattern=r"David Fis?zel",
            ),
            Contact(
                'David Rowland',
                f"{PRINCE_ANDREW}'s trusted money man at Banque Havilland whom Epstein does not trust",
                match_partial=None,
            ),
            Contact('Ted Forstmann', "private equity, founder of Forstmann Little & co."),
            Contact(
                JES_STALEY,
                "former CEO of Barclays, allegations by multiple Epstein victims",
                r"J(ames|es) (E\.? )?Staley",
                link_to_bio='https://www.theguardian.com/us-news/2026/feb/05/jes-staley-barclays-rape-allegation-us-prosecutors-epstein',
            ),
            Contact(
                JIDE_ZEITLIN,
                f"former partner at {GOLDMAN_SACHS}, Kate Spade, #MeToo allegations",
                link_to_bio='https://www.propublica.org/article/the-bizarre-fall-of-the-ceo-of-coach-and-kate-spades-parent-company',
                match_partial='both',
            ),
            Contact('Ira Zicherman', f"former {BEAR_STEARNS} exec, co-trustee of J. Epstein Foundation with Ghislaine"),
            Contact(JAMES_CAYNE, f"CEO of {BEAR_STEARNS}, executor of Epstein's will"),
            Contact('John Paulson', f"hedge fund guy, Trump donor"),
            Contact('Jonathan Rowland', f"Banque Havilland", match_partial=None),
            Contact('Kamila Bobinska', f"Argan Capital Advisors, Dots Ventures, Movens Capital, ex-{DEUTSCHE_BANK}"),
            Contact('Laurie Cameron', "currency trading"),
            Contact(
                LEON_BLACK,
                'Apollo CEO, paid Epstein more than $150 million for "tax advice", serious allegations by multiple Epstein victims',
                r"Leon\s*Black?|(?<!Marc )Leon(?! (Botstein|Jaworski|Wieseltier))",
                link_to_bio='https://x.com/kevinnbass/status/2027255769595302219',
                match_partial=None,
            ),
            Contact(MELANIE_SPINELLA, f"representative of {LEON_BLACK}", r"M?elanie Spine[Il]{2}a"),
            Contact(MICHAEL_FOWLER, f"{ATORUS} / Red Dot Trade fund co-founder", match_partial=None),
            Contact('Michael Milken', 'infamous junk bond king who went to prison in the 1980s', r"(Mi(chael|ke) )?Milken( Conference|Institute)?"),
            Contact(
                MORTIMER_ZUCKERMAN,
                "business partner of Epstein, publisher of New York Daily News and US News & World Report",
                r"Mortimer( B\.?)? Zuckerman",
                link_to_bio='https://prospect.org/2026/02/26/newspapers-did-not-kill-themselves-jeffrey-epstein-mort-zuckerman-daily-news/',
            ),
            Contact(NORMAN_D_RAU, "managing director at Morgan Stanley", match_partial=None),
            Contact(PAUL_BARRETT, r"Alpha Group Capital", r"Paul Barre(d|tt)|Barrett,? Paul( S)?", match_partial=None),
            Contact(
                PAUL_MORRIS,
                f"Epstein's primary private banker at JP Morgan then {DEUTSCHE_BANK}",
                r"morris, paul|Paul Morris",
                link_to_bio='https://fortune.com/2025/10/08/deutsche-bank-and-jeffrey-epstein-ghost/',
                match_partial=None,
            ),
            Contact('Paul Tudor Jones', "hedge fund guy, Robin Hood Foundation founder", match_partial='first'),
            Contact('Skip Rimer', "Michael Milken's Milken Institute"),
            Contact('Steven Elkman', f"{DEUTSCHE_BANK}"),
            Contact('Stephen Schwarzman', 'CEO of Blackstone', r"(Ste(phen|ve) )?Schwart?z?man"),
            Contact(TANCREDI_MARCHIOLO, "hedge fund manager, Bremner Capital Management", match_partial='both'),
            Contact('Vahe Stepanian', "Cetera Financial Group", match_partial='both'),
            Contact(VINIT_SAHNI, f"analyst at {DEUTSCHE_BANK} and {GOLDMAN_SACHS}", match_partial='both'),
            acronym("Grantor Retained Annuity Trust", "tax shelter structure favoured by Epstein"),
            organization(
                ATORUS,
                'AKA "Red Dot Trade Finance", fund of Michael Fowler / Joshua Levy apparently invested in by Epstein',
                r"Atorus( International)?"
            ),
            organization(
                'Banque Havilland',
                f"Rowland family private bank in Luxembourg used by {PRINCE_ANDREW}, charter revoked in 2024 for money laundering",
                r"(Banque )?Havilland",
                link_to_bio='https://en.wikipedia.org/wiki/Banque_Havilland',
            ),
            organization(BEAR_STEARNS, 'investment bank where Epstein got his first job in finance, failed in 2008', r"Bear Stea?rns"),
            organization(
                'Boothbay',
                f'fund run by Ari Glass whom Epstein called "a bit sketchy" but invested $50 million with',
                r"Booth\s*bay(\s(Fund\sManagement|(Absolute|Enhanced|Multi)( Return)?( Strateg(ies|y))?( Fund)?))?",
            ),
            organization(
                DEUTSCHE_BANK,
                'favoured bank of Jeffrey Epstein, the Trump family, and Russian money launderers',
                r"Deutsche? (Asset|(Post)?Bank)|\bDB\b(?!\s+Zw)",
                link_to_bio='https://www.ft.com/content/b1d9e8c4-1874-4c82-941d-9a2e1512bc4c',
            ),
            organization("FirstBank", 'Puerto Rican bank used by Epstein', r"First Bank( of Puerto Rico)?"),
            organization('Goldman Sachs', emailer_pattern=r"Goldman( Sachs)?", is_interesting=False),
            organization('Julius Baer', 'Swiss bank'),
            organization('Lazard', 'UK financial advisory and asset management firm'),
            organization('Silvergate Bank', 'crypto friendly bank that failed after the FTX crisis', r"Silver Gate( Bank)?"),
        ],
        patterns=[
            r"Ace Greenberg",
            r"AIG",
            r"Andrew Nikou",
            r"Apollo",
            r"Bank of Scotland",
            r"Bayerische Landesbank",
            r"(Bernie )?Madoff",
            r"Black(rock|stone)",
            r"B of A",
            r"BHF Bank",
            r"Charles Schwab",
            r"Chase Bank",
            r"Cheetah Investment( Management)?",
            r"Conrad B",
            r"Credit Suisse",
            r"DAF",
            r"D\.?B\.? Zwirn",
            r"Drexel",
            r"Electron Capital( Partners)?",
            r"Fenner",
            r"Fortress( Investment)? Group",
            r"FRBNY",
            r"GRAT",
            r"Gratitude (America|& Enhanced)",  # Leon Black and/or Epstein charity?
            r"Hank Greenburg",
            r"HSBC",
            r"Invesco",
            r"Jamie D(imon)?",
            r"(Janet )?Yellen",
            r"(Jerome )?Powell(?! M\. Cabot)",
            r"(Jimmy )?Cayne",
            r"Joon Yun",
            r"j\.?p\.? morgan(\.?com| Chase)?( Bank)?",
            r"JPMC?",
            r"Lehman( Brothers)?",
            r"Merrill( Lynch)?",
            r"(Michael )?Cembalest",
            r"MLPF&S",
            r"moneyland",
            r"Morgan Stanley",
            r"OpenGate Capital(, LLC)?",
            r"(Peter L. )?Scher",
            r"(Ray )?Dalio",
            r"(Richard )?LeFrak",
            r"Rockefeller(?! University)( Foundation)?",
            r"Scott Shay",
            r"SBNY",
            r"Serageldin",
            r"Signature Bank",
            r"Stone Ridge",
            r"Susquehanna",
            r"Teneo Capital",
            r"UBS",
            r"us.gio@jpmorgan.com",
        ],
    ),
    HighlightedNames(
        label=FRIEND,
        style='tan',
        contacts=[
            Contact(
                ANDREW_FARKAS,
                "heir to Alexander's department store fortune who has claimed he barely knew Epstein",
                r"Andrew (L\.? )?Farkas|Farkas, Andrew( L\.?)?",
                link_to_bio='https://www.nytimes.com/2026/02/09/nyregion/farkas-epstein-lawsuit-ties.html',
            ),
            Contact(
                DAVID_STERN,
                f"Epstein's partner in various businesses including Asia Gateway Ltd.",
                r"David Ste(m|rn?)|ds[@®]witangroup",
                match_partial=None
            ),
            Contact('Douglas Leese', 'British arms dealer / defense contractor'),
            Contact(
                JENNIE_SAUNDERS,
                f'co-founder of Core Club, {DANGENE_AND_JENNIE_ENTERPRISE}, accused of recruiting underage girls',
                r"Core Club|(Dangene and )?Jennie (Enterprise?s?|Saunders)",
                link_to_bio='https://www.crainsnewyork.com/real-estate/core-club-founder-jennie-enterprise-exchanged-thousands-emails-jeffrey-epstein',
                match_partial=None,
            ),
            Contact('Jill Iscol', 'heiress, philanthropist, IF Hummingbird Foundation'),
            Contact(
                JONATHAN_FARKAS,
                f"son of {ANDREW_FARKAS}, heir to department store fortune, spouse of Trump's ambassador to Malta",
                r"Jonath[ao]n Fark(a|u)(s|il)",
                link_to_bio='https://www.yahoo.com/news/articles/jeffrey-please-help-humiliating-emails-032309827.html',
                match_partial=None,
            ),
            Contact(
                JOSHUA_FINK,
                f"son of Blackrock CEO Larry Fink (world's largest money manager), dated {SVETLANA_POZHIDAEVA}",
                r"Josh(ua)? Fink",
                link_to_bio='https://nypost.com/2012/06/01/fink-kid-is-a-big-fat-loser/',
                match_partial=None
            ),
            Contact('linkspirit', "Skype username of someone Epstein communicated with"),
            Contact(
                'Perry Bard',
                f"{PALM_BEACH} chiropractor whose phone number came up in Epstein victim investigations",
                match_partial=None,
            ),
            Contact('Peter Thomas Roth', "student of Epstein at Dalton, skincare company founder", match_partial=None),
            Contact('Philip Diaz', match_partial=None),
            Contact('Philip Kafka', f"president of Prince Concepts (son of {TERRY_KAFKA}?)", match_partial=None),
            Contact('Rob Goldsamt', 'CEO of Basic Care Networks'),
            Contact('Sam Jaradeh', f"business partner of {BORIS_NIKOLIC}"),
            Contact(STEPHEN_HANSON, emailer_pattern=r"ste(phen|ve) hanson?|Shanson900"),
            Contact(TERRY_KAFKA, "CEO of Impact Outdoor (highway billboards), lifelong friend of Epstein", match_partial=None),
            Contact(TOM_BARRACK, "long time friend of Trump", link_to_bio='https://en.wikipedia.org/wiki/Tom_Barrack'),
            Contact('Warren Eisenstein', 'childhood friend of Epstein'),
        ],
        patterns=[
            r"Jonanthan and Kimberly Farkus",
            r"Thomas (J\.? )?Barrack( Jr)?",
        ],
    ),
    HighlightedNames(
        label=Neutral.GOVERNMENT,
        style='color(24) bold',
        contacts=[
            Contact(
                name=ALISON_J_NATHAN,
                info="judge in New York's Southern District",
                emailer_pattern=r"Alison( J\.?)? Nathan|Nathan NYSD Chambers?",
                match_partial=None,
            ),
            Contact(
                name=ANN_MARIE_VILLAFANA,
                info="Southern District of Florida (SDFL) U.S. Attorney",
                emailer_pattern=r"Villafana, Ann Marie|(A(\.|nn) Marie )?Villafa(c|n|ri)a",
            ),
            Contact(AUDREY_STRAUSS, "USA Attorney", r"Audrey Strauss|Strauss, Audrey", match_partial=None),
            Contact(
                'Barry Krischer',
                "prosecutor in charge of Epstein's sweetheart deal in 2006",
                r"(Barry (E. )?)?Krischer",
                link_to_bio='https://www.palmbeachpost.com/story/news/2024/07/10/jeffrey-epstein-first-prosecutor-barry-krischer-who-is-he/72676205007/',
            ),
            Contact(
                BEN_LAWSKY,
                f"head of NY Dept of Financial Services (NYDFS), 2nd most powerful financial regulator in the US",
                link_to_bio='https://en.wikipedia.org/wiki/Benjamin_Lawsky',
            ),
            Contact(CHRISTOPHER_DILORIO, "self described whistleblower", r"Chris(topher )? Di[lI]o[nr](io)?"),
            Contact(
                'Cyrus Vance Jr.',
                'Manhattan District Attorney 2010-2021',
                r"Cyrus Vance(,? Jr\.?)?",
                link_to_bio='https://www.politico.com/states/new-york/city-hall/story/2020/01/23/sexual-assault-survivors-call-on-cy-vance-jr-to-resign-1253915',
                match_partial=None,
            ),
            Contact(
                name=DANNY_FROST,
                info="Director of Communications at Manhattan District Attorney",
                emailer_pattern=r"Frost, Danny|frostd@dany.nyc.gov|Danny Frost",
                match_partial=None,
            ),
            Contact('Florence Hutner', "New York Office of Chief Medical Examiner", match_partial=None),
            Contact('Gary Gensler', 'future head of the SEC'),
            Contact("Geoff Ling", "director of DARPA Biological Technologies Office", r"Geoff(rey)? Ling", match_partial=None),
            Contact('Justin Alfano', f"American {LAW_ENFORCEMENT}"),
            Contact(
                LUKE_D_THORBURN,
                "informant, ex-Goldman Sachs, Paraguay",
                link_to_bio='https://www.nytimes.com/2016/03/01/nyregion/goldman-sachs-puts-worker-linked-to-donald-trump-on-leave.html',
            ),
            Contact(
                'Michael Reiter',
                f"{PALM_BEACH_POLICE} chief who first caught Epstein",
                link_to_bio='https://www.bbc.com/news/articles/cx2407jrn83o',
            ),
            Contact('Paula Speer', "court reporter", match_partial=None),
            Contact(
                'Regina Dugan',  # EFTA02009735
                'Google, Motorola, former head of DARPA',
                link_to_bio='https://www.engadget.com/2012-03-12-darpa-director-exits-agency-for-google-assumes-mysterious-role.html',
                match_partial=None,
            ),
            acronym('Foreign Corrupt Practices Act'),
            acronym('Justice Against Sponsors of Terrorism Act', 'law permitting 9/11 survivors to sue Saudi Arabia'),
            acronym('Know Your Customer', 'anti-money laundering legal framework'),
            acronym('Metropolitan Detention Center', 'jail where Epstein died'),
            acronym('Office of Foreign Assets Control', 'agency in charge of sanctions'),
            acronym('Office of the Comptroller of the Currency'),
            acronym('Office of Government Ethics'),
            organization('BaFin', "German financial regulator, tried to arrest journalists who exposed Wirecard's fraud"),
            organization('FINRA', "Financial Industry Regulatory Authority", r"(www\.)?FINRA(\.org)?|Financial Industry Regulatory Authority",),
            organization('INS', "US Immigration and Naturalization Service", r"(?-i:INS)"),
            organization('FinCEN', 'Financial Crimes Enforcement Network', r"(Director (of )?)?(Financial Crimes Enforcement Network|FinCEN)"),
            organization(
                SECURITIES_AND_EXCHANGE_COMMISSION,
                "AKA 'SEC', US market regulator",
                r"sec\.?gov|Securities (&|and) Exchange Commission",
            ),
            law_enforcement(BUREAU_OF_PRISONS, r"bop\.gov|(Federal )?Bureau of Prisons"),
            law_enforcement('DOJ Inspector General'),
            law_enforcement('DOJ London'),
            law_enforcement(FBI),
            law_enforcement('Manhattan DA'),
            law_enforcement('NY FBI'),
            law_enforcement(OFFICE_OF_THE_DEPUTY_ATTORNEY_GENERAL, r"\bODAG\b"),
            law_enforcement('Police Code Enforcement', description=f"{PALM_BEACH} buildings code enforcement"),
            law_enforcement(SDNY),
            law_enforcement('USAHUB-USAJournal111'),
            law_enforcement(USANYS),
            law_enforcement('USMS'),
        ],
        patterns=[
            r"(?<!Data\s)AG",
            r"(Alicia )?Valle",
            r'Alice Fisher|Fisher, Alice',
            r"AML",
            r"(Andrew )?(McCabe|Natsios)",
            r"(Assistant )?State Attorney",
            r"Attorneys? General",
            r"Bank Secrecy Act",
            r'Barbara Burns',  # AUSA
            r"((Bob|Robert) )?Mueller",
            r"BSA",
            r"(Byung )?(J\. )?Pak",
            r"Case 1:19-cv-03377(-LAP)?",
            r"(CENT|NORTH|SOUTH)COM",
            r"CFTC?",
            r"CIA",
            r"CIS",
            r"CTR",  # Currency Transaction Report
            r"CVRA",
            r"DARPA",
            r"Dep(artmen)?t\.? of (the )?(Justice|Treasury)",
            r"DHS",
            r"DOJ",
            r"FCPA",
            r"FDIC",
            r"FDLE",
            r"Federal Bureau of Investigation",
            r"FOIA",
            r"food stamps",
            r"FTC",
            r"(General )?P(a|e)traeus",
            r"Homeland Security",
            r"IG",
            r"Interpol",
            r"IRS",
            r"(James )?Comey",
            r"(Jennifer Shasky )?Calvery",
            r"((Judge|Mark) )?(Carney|Filip)",
            r"(Judge )?(Kenneth )?(A\.? )?Marra",
            r"(Justice|Treasury) Dep(t|artment)",
            r"(Kirk )?Blouin",
            r"(Kurt )?(L\.? )?Gottschall",
            r"(Lann?a )?Belohlavek",
            r"law enforcement",
            r"NIH",
            r"NPA",
            r"NS(A|C)",
            r"NYDFS",
            r"NYPD",
            r"PBPD",
            r"police",
            r"POTUS",
            r"(Preet )?Bharara",
            r"Public Corruption Unit",
            r"SAR",
            r"SCOTUS",
            r"SD(FL|NY)",
            r"(?-i:SEC)( filing)?",
            r"Southern District( of (Florida|New York))?",
            r"State Dep(artmen)?t",
            r"(Peter? )?Strzok",
            r"Supreme Court",
            r"TCR",
            r"Treasury (Dep(artmen)?t|Secretary)",
            r"TSA",
            r"U\.?S\.? attorney",
            r"USAID",
            r"UNITED STATES DISTRICT COURT?",
            r"US (AF|Army|Air Force)",
            r"USSS",
            r"(U\.?S\.? )?Secret Service",
            r"Walter Reed( Army Institute of Research)?",
            r"whistleblower",
            r"(William J\.? )?Zloch",  # Judge
            r"WRAIR",
        ],
    ),
    HighlightedNames(
        label=HARVARD,
        style='light_goldenrod3',
        contacts=[
            Contact('Donald Rubin', "Professor of Statistics", match_partial=None),
            Contact('Henry Rosovsky', f'emeritus dean of {HARVARD}', r"(Henry )?Rosovs(k|lc)y"),
            Contact('Kelly Friendly', f"longtime aide and spokesperson of {LARRY_SUMMERS}", match_partial=None),
            Contact(
                LARRY_SUMMERS,
                "board of Digital Currency Group (DCG), Obama economic advisor",
                r"(La(wrence|(n|rr)y).{1,5})?Summers?|^LH$|LHS|[Il]hsofficel?",
                link_to_bio='https://protos.com/larry-summers-gives-up-advisory-role-at-crypto-firm-dcg-amid-criticism/',
            ),
            Contact('Leah Reis-Dennis', f"producer for {LISA_NEW}'s Poetry in America"),
            Contact(
                LISA_NEW,
                f'professor of poetry, wife of {LARRY_SUMMERS}, AKA "Elisa New"',
                r"E?Lisa New?\b",
                match_partial=None,
            ),
            Contact(LISA_RANDALL, "theoretical physicist", match_partial=None),
            Contact(
                MARTIN_NOWAK,
                "professor of mathematics and biology",
                r"(Martin.*?)?No[vw]ak|Nowak, Martin",
                link_to_bio='https://www.thecrimson.com/article/2026/2/25/nowak-leave-epstein/',
            ),
            Contact(MOSHE_HOFFMAN, "behavioral and evolutionary economics", match_partial=None),
            Contact('Steve Kosslyn', "neuroscientist, Active Learning Sciences"),
        ],
        patterns=[
            r"Cambridge",
            r"(Derek )?Bok",
            r"Harvard( (Business|Law|University)( School)?)?",
            r"(Jonathan )?Zittrain",
            r"Poetry in America",
        ],
    ),
    HighlightedNames(
        label='India',
        style='bright_green',
        contacts=[
            Contact(ANIL_AMBANI, "billionaire chairman of Reliance Group", r"Anil.Ambani"),
            organization(
                'InsightsPod',
                f"{ZUBAIR_KHAN} and {ANYA_RASULOVA}'s company recommended by {MARIA_PRUSAKOVA}, did social media work for Epstein during the 2016 election",
                link_to_bio=SUBSTACK_INSIGHTS_POD
            ),
            organization('Tranchulas', f'cybsecurity firm of {ZUBAIR_KHAN}, provider of offensive hacking services'),
        ],
        patterns=[
            r"Abraaj",
            r"Anna Hazare",
            r"(Arif )?Naqvi",
            r"(Arvind )?Kejriwal",
            r"Bangalore",
            r"Hardeep( Pur[ei]e)?",
            r"Indian?",
            r"Mombasa",
            r"Modi",
            r"Mumbai",
            r"(New )?Delhi",
        ],
    ),
    HighlightedNames(
        label='Israel',
        style='dodger_blue2',
        contacts=[
            Contact(
                EHUD_BARAK,
                "former prime minister of Israel, Epstein business partner",
                r"(ehud|e?h) barac?k|\behud",
                link_to_bio='https://en.wikipedia.org/wiki/Ehud_Barak',
            ),
            Contact('Mitchell Bard', "director of the American-Israeli Cooperative Enterprise (AICE)", match_partial=None),
            Contact(NILI_PRIELL_BARAK, f"wife of {EHUD_BARAK}", r"Nili Priell?", match_partial=None),
            organization(
                'Bank Leumi',
                'Israeli bank that helped Americans avoid taxes',
                r"(Bank )?Leumi",
                link_to_bio='https://www.justice.gov/archives/opa/pr/bank-leumi-admits-assisting-us-taxpayers-hiding-assets-offshore-bank-accounts',
            ),
            organization(
                CARBYNE,
                f'FKA "Reporty", Israeli co. invested in by Epstein, {EHUD_BARAK}, and {NICOLE_JUNKERMANN}',
                r"Carbyne|Reporty",
                link_to_bio='https://www.forbes.com/sites/thomasbrewster/2026/02/10/epstein-police-surveillance-investments-with-ehud-barak/',
            ),
            organization(
                'Hapoalim',
                f"largest bank in Israel, convicted of enabling tax evasion, fraud, and money laundering",
                link_to_bio='https://www.justice.gov/usao-edny/pr/bank-hapoalim-agrees-pay-more-30-million-its-role-money-laundering-conspiracy-involving',
            ),
            organization("Mizrahi Bank", '3rd largest bank in Israel'),
        ],
        patterns=[
            r"AIPAC",
            r"Bibi",
            r"(eh|(Ehud|Nili Priell) )?barak",
            r"EB",
            r"Idan Ofer",
            r"Israeli?",
            r"Jerusalem",
            r"J Street",
            r"Menachem Begin",
            r"Mossad",
            r"(Benjamin|Binyamin|Yair )?Netanyahu",
            r"(Sheldon )?Adelson",
            r"Tel Aviv",
            r"(The )?Shimon Post",
            r"Yitzhak", r"Rabin",
            r"YIVO",
            r"Yoni Koren",
            r"zionists?",
        ],
    ),
    # HighlightedNames(
    #     label='Japan',
    #     style='color(168)',
    #     patterns=[
    #     ],
    # ),
    HighlightedNames(
        label=JOURNALIST,
        style='bright_yellow',
        contacts=[
            Contact('Adam Bly', "editor of SEED magazine"),
            Contact('Alain Forget', "author of \"How To Get Out Of This World ALIVE\"", match_partial=None),
            Contact('Alex Yablon', "New York Magazine fact checker (?)"),
            Contact(
                'Conchita Sarnoff',
                'journalist Epstein attempted to bribe',
                r"Con[cs]hita( Sarnoff)?",
                link_to_bio='https://conchitasarnoff.com/',
                match_partial='both',
            ),
            Contact('Chris Cuomo', 'newscaster, brother of NY governor Andrew Cuomo', r"Chris(topher)? Cuomo", match_partial=None),
            Contact(
                'Dan Dubno',
                'producer and technologist for CBS News in New York',
                link_to_bio='https://www.edge.org/memberbio/dan_dubno',
            ),
            Contact('David Pecker', 'lowlife publisher of National Enquirer and Weekly World News'),
            Contact(
                'Dylan Love',
                f'Business Insider / The Next Web, financial support from Epstein via {MASHA_DROKOVA}',
                match_partial=None,
            ),
            Contact(
                EDWARD_JAY_EPSTEIN,
                "no relation, wrote books about spies",
                r"(?<!Jeffrey )Edward (Jay )?Epstein",
                link_to_bio='https://www.godofthedesert.org/p/the-secrets-edward-jay-epstein-told',
                match_partial=None,
            ),
            Contact(
                'Graydon Carter',
                f"editor of Vanity Fair",
                link_to_bio='https://www.newyorker.com/news/annals-of-communications/why-didnt-vanity-fair-break-the-jeffrey-epstein-story',
                match_partial='first',
            ),
            Contact(JAMES_HILL, "ABC News", r"hill, james e.|james.e.hill@abc.com", match_partial=None),
            Contact(JENNIFER_JACQUET, "Future Science magazine"),
            Contact(
                JOHN_BROCKMAN,
                "literary agent and author specializing in scientific literature",
                link_to_bio='https://lunch.publishersmarketplace.com/2026/02/reports-detail-how-literary-agent-brockman-connected-epstein-with-scholars/',
            ),
            Contact(
                JULIE_K_BROWN,
                'blew the lid on the 2006 Epstein sweetheart deal',
                r"Julie (K.? )?Brown|jbrown@miamiherald.com",
                match_partial=None,
            ),
            Contact(LANDON_THOMAS, "New York Times financial reporter", r"lando[nr] thomas( jr)?|thomas jr.?, lando[nr]"),
            Contact(
                name=MICHAEL_WOLFF,
                info="author of \"Fire and Fury: Inside the Trump White House\"",
                emailer_pattern=r"Michael Wol(f[ef]e?|i)|Wolff",
            ),
            Contact(PAUL_KRASSNER, "60s counterculture guy, Merry Prankster", r"Pa\s?ul Krassner"),
            Contact('Peter Aldhous', "Buzzfeed science reporter"),
            Contact('Susan Edelman', "New York Post reporter", match_partial=None),
            Contact('Tim Zagat', "Zagat restaurant guide CEO"),
            Contact(
                'Vicky Ward',
                "coverage of Epstein allegations was spiked by editors in 2003, went on to publicly praise Epstein and Ghislaine as great people in 2011",
                r"Vick[iy] Ward",
                link_to_bio='https://www.npr.org/2019/08/22/753390385/a-dead-cat-a-lawyers-call-and-a-5-figure-donation-how-media-fell-short-on-epstei',
                match_partial=None,
            ),
            organization('Effective Altruism', 'cult popular with tech CEOs who want an excuse for hoarding money (e.g. SBF of FTX)'),
            organization('Futurism', f'odd outlet that seems hooked up with {MASHA_DROKOVA}'),
            organization('Gawker', f'independent news site killed by a Hulk Hogan lawsuit funded by {PETER_THIEL}'),
            organization(HENRY_HOLT, f"{MICHAEL_WOLFF}'s book publisher"),
            organization('Newsmax', "right wing American news outlet", r"Newsmax(\.com)?", is_emailer=True),
            organization('Techonomy', "tech news outlet publishing pieces about Epstein's philanthropy"),
            organization('US News & World Report', emailer_pattern=r"US News (and|&) World Report"),
        ],
        patterns=[
            r"ABC( News)?",
            r"Alexandra Wolfe|Wolfe, Alexandra",
            r"AlterNet",
            r"Arianna( Huffington)?(?! Simpson)",
            r"(Arthur )?Kretchmer",
            r'Associated Press',
            r"Axios",
            r"BBC",
            r"(Bob|Robert) (Costa|Woodward)",
            r"Breitbart",
            r"BuzzFeed( News)?",
            r"C-?Span",
            r"CBS( (4|Corp|News))?",
            r"Charlie Rose",
            r"China Daily",
            r"(C|MS)?NBC( News)?",
            r"CNN(politics?)?",
            r"Daily Business Review",
            r"(?<!Virgin[-\s]Islands[-\s])(The\s*)?Daily\s*(Beast|Mail|News|Telegraph)",
            r"David Brooks",
            r"Ed Krassenstein",
            r"(Emily )?Michot",
            r"Ezra Klein",
            r"Fire and Fury",
            r"Forbes",
            r"Fortune Magazine",
            r"Fox News(\.com)?",
            r"FrontPage Magazine",
            r"FT",
            r"(George )?Stephanopoulus",
            r"Ger(ald|ry) Baker",
            r"Globe and Mail",
            r"Good Morning America",
            r"Hollywood Reporter",
            r"Huff(ington)?( Po(st)?)?",
            r"Ingram, David",
            r"James Hill",
            r"(James )?Patterson",
            r"Jeff Tollefson",
            r"Jesse Kornbluth",
            r"John Connolly",
            r"Jonathan Karl",
            r"Journal of Criminal Law and Criminology",
            r"(Katie )?Couric",
            r"Keith Larsen",
            r"L\.?A\.? Times",
            r"Law(360|\.com|fare)",
            r"(Les )?Moonves",
            r"MarketWatch",
            r"Miami Herald",
            r"(Mi(chael|ke) )?Bloomber[gq]( News)?",
            r"(Michele )?Dargan",
            r"Morning News USA",
            r"(National )?Enquirer",
            r"News(max|week)",
            r"NY(er| mag(azine)?)",
            r"Palm Beach (Daily News|Post)",
            r"PERVERSION OF JUSTICE",
            r"Politico",
            r"Pro Publica",
            r"(Sean )?Hannity",
            r"Sharon Churcher",  # Daily Mail
            r"Sulzberger",
            r"SunSentinel",
            r"tabloid",
            r"(The )?Financial Times",
            r"The Guardian",
            r"TheHill",
            r"(?<!Mobile\s)(The )?Mail On Sunday",
            r"(The )?N(ew )?Y(ork)? (Magazine|Observer|P(ost)?|T(imes)?)",
            r"(The )?New Yorker",
            r"(The )?Wall Street Journal",
            r"(The )?Wa(shington )?Po(st)?",
            r"(Thomson )?Reuters",
            r"T(homas|om) Friedman",
            r"(Uma )?Sanghvi",
            r"USA Today",
            r"Vanity Fair",
            r"Viceland",
            r"Vox",
            r"WGBH",
            r"WSJ",
            r"[-\w.]+@(bbc|independent|mailonline|mirror|thetimes)\.co\.uk",
        ],
    ),
    HighlightedNames(
        label=Uninteresting.JUNK,
        style='gray46',
        contacts=[
            Contact('asmallworld@travel.asmallworld.net'),
            Contact('digest-noreply@quora.com'),
            Contact('editorialstaff@flipboard.com'),
            Contact('How To Academy', is_junk=True),
            Contact('Jokeland')
        ],
        should_match_first_last_name=False,
    ),
    HighlightedNames(
        label='Latin America',
        style='yellow',
        contacts=[
            Contact('Edgar Zambrano', 'Venezuelan politician'),
            Contact(
                REINALDO_AVILA_DA_SILVA,
                "Peter Mandelson's Brazilian partner",
                r"Reinaldo Avila( da Silva)?",
                match_partial=None,
            ),
        ],
        patterns=[
            r"Argentin(a|ian)",
            r"Bolsonar[aio]",
            r"Bra[sz]il(ian)?",
            r"Caracas",
            r"Castro",
            r"Chile",
            r"Colombian?",
            r"Cuban?",
            r"Ecuador(ian(s)?)?",
            r"el chapo",
            r"El Salvador",
            r"((Enrique )?Pena )?Nieto",
            r"Guatemalan?",
            r"Honduran?s?",
            r"Lat(in)? Am(erican?)?",
            r"Lula",
            r"(?<!New )Mexic(an|o)",
            r"(Nicolas )?Maduro",
            r"Panama( Papers)?",
            r"Peru(vian)?",
            r"Salvadoran",
            r"South American?",
            r"Venezuelan?",
            r"Yucatan( Peninsula)?",
        ],
    ),
    HighlightedNames(
        label=LOBBYIST,
        style='dark_khaki',
        contacts=[
            Contact(BOB_CROWE, "partner at Nelson Mullins", r"[BR]ob Crowe", match_partial=None),
            Contact('Joshua Cooper Ramo', "co-CEO of Henry Kissinger Associates"),
            Contact(OLIVIER_COLOM, f"Epstein's banker at {EDMOND_DE_ROTHSCHILD} (Suisse) SA Bank", r"Colom, Olivier?|Olivier Colom"),
            Contact('Paul Keating', "former prime minister of Australia", match_partial=None),
            Contact('Stanley Rosenberg', "former President of the Massachusetts Senate", match_partial=None),
            Contact('Vinoda Basnayake', f'Nelson Mullins Riley, worked on getting {KARIM_WADE} out of jail'),
            Contact('Elisabeth Feliho', f'Nelson Mullins Riley, worked on getting {KARIM_WADE} out of jail'),
            acronym('Center for Strategic and International Studies', 'pro-war American think tank'),
        ],
        patterns=[
            r"(Kevin )?Rudd",
        ],
    ),
    HighlightedNames(
        label='Mongolia',
        style='light_coral',
        contacts=[
            Contact(
                GANBAT_CHULUUNKHUU,
                "corrupt Mongolian politician who was later wanted by Interpol",
                r"Ganbat(@| Ch(uluunkhuu)?)?|gambahtss?",
                link_to_bio='https://news.mn/en/227194/',
                match_partial='both',
            ),
            Contact('Khaltmaagiin Battulga', "former president of Mongolia", match_partial='both'),
            Contact(PUREVSUREN_LUNDEG, "Mongolian ambassador to the UN", r"Purevsuren( Lundeg)?", match_partial='both'),
        ],
        patterns=[
            r"Batzaya",
            r"Enkhbajar",
            r"Kosov(ar|o)",
            r"Moldovan?",  # because it's between russia + EU
            r"Mongolian?",
            r"(President )?Elbe[gk]dorj",
            r"Ulaan Ba?atar",
        ]
    ),
    HighlightedNames(
        label=MIDEAST,
        style='dark_sea_green4',
        contacts=[
            Contact(
                'Adnan Khashoggi',
                'arms dealer involved in the Iran-Contra scandal, Epstein\'s former employer',
                r"kasshohgi|Kh?ashoggi",
            ),
            Contact(
                ANAS_ALRASHEED,
                f"former information minister of Kuwait {QUESTION_MARKS}",
                r"anas al rashee[cd]",
                link_to_bio='https://www.ku.edu.kw/user/5440'
            ),
            Contact(
                AZIZA_ALAHMADI,
                f"Abu Dhabi Department of Culture & Tourism, assistant of {RAAFAT_ALSABBAGH}",
                link_to_bio='https://x.com/DropSiteNews/status/2019199114534350961',
                match_partial='both',
            ),
            Contact(
                name=FAWZI_SIAM,
                info="sharia auditor in Qatar, friend of Sheikh Jabor Al-Thani",
                emailer_pattern=r"Fawzi.Siam?",
                match_partial='first',
            ),
            Contact('Hamad bin Khalifa al-Thani', 'emir of Qatar', match_partial=None),
            Contact(
                HASSAN_JAMEEL,
                'scion of Saudi family, Abdul Latif Jameel',
                r"Hassan (Mohammed )?(Abdul )?(.atif )?Jameel",
                link_to_bio='https://en.wikipedia.org/wiki/Hassan_Jameel',
            ),
            Contact('Hayel Besher', f"relative of {SHAHER_ABDULHAK_BESHER} {QUESTION_MARKS}"),
            Contact(
                'Kairat Kelimbetov',
                'former deputy prime minister of Kazakhstan',
                link_to_bio='https://en.wikipedia.org/wiki/Kairat_Kelimbetov',
                match_partial='both'
            ),
            Contact("Mohammed bin Salman", 'AKA "MBS", prince of Saudi Arabia', r"Mohammed bin Salman|MBS", match_partial=None),
            Contact('Mohammed bin Zayed', 'AKA "MBZ", ruler of Abu Dhabi', r"Mohamed bin Zayed|MBZ", match_partial=None),
            Contact(
                'Muhammad bin Nayef',
                'AKA "MBN", former crown prince of Saudi Arabia',
                r"M[ou]hamm[ae]d bin Nayef|MBN",
                match_partial=None,
            ),
            Contact('Nursultan Nazarbayev', 'former president of Kazakhstan', match_partial='both'),
            Contact('Dariga Nazarbayeva', 'daughter of Nursultan Nazarbayev'),
            Contact(
                'Rakhat Aliyev',
                'corrupt Kazakh politician',
                link_to_bio='https://www.bbc.com/news/world-europe-32253434',
                match_partial='both'
            ),
            Contact(
                RAAFAT_ALSABBAGH,
                "Saudi royal advisor",
                link_to_bio='https://publish.obsidian.md/findingtruth/Modern+Day+Locations/Asia/Asian+Important+People/Raafat+Al-Sabbagh',
                match_partial='both',
            ),
            Contact(
                SHAHER_ABDULHAK_BESHER,
                "Yemeni billionaire whose son fled London after murdering Martine Vik Magnussen",
                r"\b(Shaher( Abdulhak Besher)?)\b",  # NOTE: Shaher has custom handling for "S A" in emailers.py
                link_to_bio='https://en.wikipedia.org/wiki/Murder_of_Martine_Vik_Magnussen',
            ),
            Contact('Timur Kulibayev', 'businessman from Kazakhstan'),
            organization('GCC', 'Gulf Cooperation Council', r"GCC|Gulf Cooperation Council"),
            organization('Halkbank', 'Turkish bank charged with evading sanctions on Iran, pardoned by Trump', r"Halk Bank(asi)?"),
            organization('Rayyan Bank', 'Islamic bank based in Qatar'),
        ],
        patterns=[
            r"Abdulmalik Al-Makhlafi",
            r"Abdullah",
            r"Abu Dhabi",
            r"Afghanistan",
            r"Ahmadinejad",
            r"Al Qasimi",
            r"Al Qa[ei]da",
            r"Arab",
            r"Aramco",
            r"Armenia",
            r"Assad",
            r"Ayatollah",
            r"Bahrain",
            r"Basiji?",
            r"Beirut",
            r"Benghazi",
            r"Brunei",
            r"Cairo",
            r"Chagoury",
            r"Damascus",
            r"Dj[iu]bo?uti",
            r"Doha",
            r"[DB]ubai",
            r"Egypt(ian)?",
            r"Emir(at(es?|i))?",
            r"Erdogan",
            r"Fashi",
            r"Gaddafi",
            r"(Hamid )?Karzai",
            r"Hamas",
            r"Hezbollah",
            r"Hourani",
            r"Houthi",
            r"Imran Khan",
            r"((Iraq|Iran|Kuwait|Qatar|Yemen)i?)",
            r"Iran(ian)?([-\s]Contra)?",
            r"Isi[ls]",
            r"Islam(abad|ic|ist)?",
            r"Istanbul",
            r"Kabul",
            r"Kaz(akh|ich)stan",
            r"Kazakh?",
            r"Kh[ao]menei",
            r"Khalid Sheikh Mohammed",
            r"KSA",
            r"Leban(ese|on)",
            r"Libyan?",
            r"Mahmoud",
            r"Marra[hk]e[cs]h",
            r"Mid(dle)? East(ern)?",
            r"MJ",
            r"Mohammed bin Salman",
            r"Morocc(an|o)",
            r"Mosque",
            r"Mubarak",
            r"Muslim( Brotherhood)?",
            r"Nayaf",
            r"Pak[ai]stani?",
            r"Omar",
            r"OPEC",
            r"(Osama )?Bin Laden",
            r"Osama(?! al)",
            r"Palestin(e|ian)",
            r"Persian?( Gulf)?",
            r"Riya(dh|nd)",
            r"Saddam",
            r"Salman",
            r"Saudi( Arabian?)?",
            r"Shariah?",
            r"SHC",
            r"sheikh?",
            r"shia",
            r"(Sultan )?Yacoub",
            r"Sultan(?! Ahmed)",
            r"Syrian?",
            r"(Tarek )?El Sayed",
            r"Tehran",
            r"Tripoli",
            r"Tunisian?",
            r"Turk(ey|ish)?(?!s & Caicos)",
            r"UAE",
        ],
    ),
    HighlightedNames(
        label='modeling',
        style='pale_violet_red1',
        contacts=[
            Contact('Abi Schwinck', f"{JEAN_LUC_MC2} {QUESTION_MARKS}"),
            Contact('Aleksandra Rastovic', 'model, received FedEx packages from Epstein', r"Ale(ks|x)(andra)? Rasto[uv]ic|superaleksandra"),
            Contact(
                DANIEL_SIAD,
                'model scout funded by Epstein to recruit in eastern Europe',
                link_to_bio='https://en.wikipedia.org/wiki/Daniel_Siad#Connection_to_Epstein_and_Brunel',
            ),
            Contact(
                FAITH_KATES,
                "Next Models co-founder",
                r"faith kates?",
                link_to_bio='https://wwd.com/fashion-news/fashion-scoops/next-model-faith-kates-management-stays-quiet-departure-1238368757/',
                match_partial=None,
            ),
            Contact('Gianni Serazzi', "fashion consultant?"),
            Contact(HEATHER_MANN, f"South African model, ex-girlfriend of {PRINCE_ANDREW} (?)", match_partial=None),
            Contact(
                JEAN_LUC_BRUNEL,
                f"{MC2_MODEL_MGMT} founder, #MeToo problems, died like Epstein but in a French jail",
                r"Jean Luc Brunel?|JeanLuc",
                link_to_bio='https://en.wikipedia.org/wiki/Jean-Luc_Brunel',
                match_partial='both',
            ),
            Contact(
                name=JEFF_FULLER,
                info=f"president of {JEAN_LUC_MC2} USA",
                emailer_pattern=r"jeff@mc2mm.com|Jeff Fuller",
                match_partial=None,
            ),
            Contact(MANUELA_MARTINEZ, "Mega Partners (Brazilian agency)", r"Manuela (- Mega Partners|Martinez)", match_partial=None),
            Contact(MARIANA_IDZKOWSKA, 'Polish model, island visitor', r"Mariana [Il]d[źi]kowska?"),
            Contact('Michael Sanka', f"{JEAN_LUC_MC2} {QUESTION_MARKS}"),
            Contact(NAOMI_CAMPBELL, 'supermodel', match_partial=None),
            Contact('Ofer Raphaeli', f'founder of the Israeli branch of {JEAN_LUC_MC2}', link_to_bio='https://www.jpost.com/international/article-887415'),
            Contact(
                'Paolo Zampolli',
                'ID Models, allegedly tried to buy Elite Models w/Epstein, $ for passports scandal in Dominica, introduced Melania to Donald (?)',
                r"(Paolo )?Z[ae]mpoll?i",
                link_to_bio='https://dominicanewsonline.com/news/homepage/news/the-zampolli-matter-more-fuel-for-where-de-money-gone-campaign/',
            ),
            Contact(
                RAMSEY_ELKHOLY,
                f"scouted girls for Epstein in NYC, member of Monotronic",
                link_to_bio='https://ramseyelkholyny.com/',
                match_partial='both',
            ),
            # Contact('Regina', f'model, Epstein and {FAITH_KATES} tried to get her a contract'),
            Contact('Vladimir Yudashkin', "director of the 1 Mother Agency"),
            Contact('Yfke Sturm', 'model from Holland', link_to_bio='https://en.wikipedia.org/wiki/Yfke_Sturm', match_partial='both'),
            Contact('lorraine@mc2mm.com', JEAN_LUC_MC2),
            Contact('pink@mc2mm.com', JEAN_LUC_MC2, r"^Pink$|pink@mc2mm\.com"),
            Contact(
                'Tigran Khachatrian',
                'model scout, appears in "Girl Model" documentary',
                r"Tigrane?( Khachatrian)?",
                link_to_bio='https://en.wikipedia.org/wiki/Girl_Model',
                match_partial='both',
            ),
            organization('Elite Models', 'well known modeling agency'),
            organization('Icarine', f"agency with connections to {JEAN_LUC_BRUNEL}"),
            organization('ID Models', "Paolo Zampolli's modeling agency"),
            organization(MC2_MODEL_MGMT, f"{JEAN_LUC_BRUNEL} and Epstein's modeling agency", r"MC2( Model Management)?"),
            organization('Next Models', f"modeling agency co-founded by {FAITH_KATES}"),
            organization('One Model Management', 'agency'),
        ],
        patterns=[
            r"\w+@mc2mm.com",
            r"Faena",
            r"(?<!(ID|ge|te|xt)\s)model(ing|s)",
            r"noah\s*models(.com)?",
            r"Victoria's Secret",
        ],
    ),
    HighlightedNames(
        label=PUBLICIST,
        style='orange_red1',
        contacts=[
            Contact(
                AL_SECKEL,
                "Isabel Maxwell's husband, Mindshift conference organizer, mysterious death",
                link_to_bio='https://www.tabletmag.com/sections/news/articles/the-illusionist-al-seckel',
            ),
            Contact('Barnaby Marsh', "co-founder of philanthropy services company Saint Partners", match_partial=None),
            Contact(CHRISTINA_GALBRAITH, f"{JEFFREY_EPSTEIN} VI Foundation Media/PR, worked with {TYLER_SHEARS}"),
            Contact(
                IAN_OSBORNE,
                f"PR for Epstein, runs {HEDOSOPHIA} which launched SPACs with {CHAMATH_PALIHAPITIYA} advised by Epstein",
                r"[Il]an Osbou?(rn|m)e",
                link_to_bio='https://www.businessinsider.com/profile-ian-osborne-cofounder-chamath-palihapitiya-social-capital-hedosophia-spac-2021-5'
            ),
            Contact('Lila Walker', f"assistant to {PEGGY_SIEGAL}", match_partial=None),
            Contact(MATTHEW_HILTZIK, "crisis PR at Hiltzik Strategies", r"(Matt(hew)? )?Hiltzi[gk]"),
            Contact(MICHAEL_SITRICK, "crisis PR", r"(Mi(chael|ke).{0,5})?[CS]itrick"),
            Contact('Owen Blicksilver', "OBPR, Inc."),
            Contact(
                PEGGY_SIEGAL,
                "socialite, movie promoter",
                r"Peggy Sieg[ae]l?",
                link_to_bio='https://en.wikipedia.org/wiki/Peggy_Siegal',
            ),
            Contact('R. Couri Hay', 'PR (?)'),
            Contact(ROSS_GOW, "Acuity Reputation Management", r"Ross(acuity)? Gow|(ross@)?acuity reputation(\.com)?"),
            Contact(
                TYLER_SHEARS,
                f"reputation management, worked on with {CHRISTINA_GALBRAITH}",
                r"T[vy]ler Shears",
            ),
            organization(HEDOSOPHIA, f"{IAN_OSBORNE} VC fund, invested in Alibaba, launched SPACs with Chamath advised by Epstein"),
            organization('Wagging Tail Entertainment', f"{PEGGY_SIEGAL} company"),
        ],
        patterns=[
            r"Philip Barden",
            r"PR Newswire",
            REPUTATION_MGMT,
            r"Reputation.com",
            r"(Robert L\. )?Dilenschneider",
        ],
    ),
    HighlightedNames(
        label='Republican',
        style='dark_red bold',
        contacts=[
            Contact(
                'Alex Acosta',
                "approved Epstein's 2007 sweetheart deal as US attorney, nominated to be Trump's Labor Secretary, resigned over Epstein",
                r"(Alex(ander)? )?Acosta",
                link_to_bio='https://www.npr.org/2019/07/12/739881163/alexander-acosta-steps-down-as-labor-secretary-amid-epstein-controversy',
            ),
            Contact('Chris Christie', 'former governor of New Jersey, Trump 1.0 transition team head', r"(Chris\s+)?Christie"),
            Contact('Darrell Issa', 'congressman described as a Russian agent by other Republicans, helped form SpaceX'),
            Contact('Don McGahn', 'White House Counsel to Trump 1.0'),
            Contact('Elliott Broidy', 'fundraiser, impregnated / paid off / paid for an abortion for a Playboy Playmate he had affair with'),
            Contact('Juleanna Glover', "CEO of D.C. public affairs advisory firm Ridgely|Walsh"),
            Contact(RUDY_GIULIANI, 'disbarred former mayor of NYC'),
            Contact(TULSI_GABBARD, 'former Democrat, National Security Advisor under Trump 2.0'),
            Contact('Nikki Haley', match_partial='both'),
        ],
        patterns=[
            r"Alberto Gonzale[sz]",
            r"Ann Coulter",
            r"(Ben )?Sasse",
            r"Betsy Devos",
            r"((Bill|William) )?Barr",
            r"Bill Shine",
            r"Blackwater",
            r"(Bob )?Corker",
            r"(Brett )?Kavanau?gh",
            r"Broidy",
            r"(?<!Merwin\sDela\s)(Ted\s+)?Cruz",
            r"Devin Nunes",
            r"Erik Prince",
            r"Gary Cohn",
            r"George (H\.? )?(W\.? )?Bush",
            r"(George )?Nader",
            r"GOP",
            r"((Chair|Jay|Joseph) )?Clayton",  # SEC chair, now SDNY
            r"((Bill|William) )?Hinman",
            r"(Henry )?Kissinger",
            r"Jeff(rey)? Sessions",
            r"(John (R.? )?)?Bolton",
            r"Kasich",
            r"Keith Schiller",
            r"Kelly( Anne?)? Conway|Kellyanne",
            r"Kobach",
            r"Kolfage",
            r"(Larry )?Kudlow",
            r"Lewandowski",
            r"(Marco )?Rubio",
            r"(Mark )Meadows",
            r"Mattis",
            r"McCain",
            r"McMaster",
            r"(Michael\s)?Hayden",
            r"((General|Mike) )?(Flynn|Pence)",
            r"(Mitt )?Romney",
            r"(Steven? )?Mnuchin",
            r"(Newt )?Gingrich",
            r"(Paul )?(Manafort|Volcker)",
            r"(Peter )?Navarro",
            r"(Mike )?Pompeo",
            r"(Ronald )?Reagan",
            r"Reince", r"Priebus",
            r"Republican",
            r"(Rex )?Till?erson",
            r"(?<!Cynthia )(Richard\s*)?Nixon",
            r"RNC",
            r"(Roy|Stephen) Moore",
            r"Tea Party",
            r"Wilbur Ross",
        ],
    ),
    HighlightedNames(
        label='Rothschild',
        style='indian_red',
        contacts=[
            Contact(
                name=ARIANE_DE_ROTHSCHILD,
                info=f"heiress, runs the bank {EDMOND_DE_ROTHSCHILD} (Suisse) SA",
                emailer_pattern=r"AdeR|(A(\.|riane) (de )?)?Roths?h?ch?il[cd]|Ariane(?! Dwyer)",
            ),
            Contact(JOHNNY_EL_HACHEM, f"{EDMOND_DE_ROTHSCHILD} Private Equity", r"el hachem johnny|johnny el hachem"),
            organization(EDMOND_DE_ROTHSCHILD, f"Swiss bank"),
        ],
        patterns=['AdR'],
    ),
    HighlightedNames(
        label='Russia',
        style='red bold',
        contacts=[
            Contact('Alexei Navalny', 'assassinated Russian opposition leader', r"Ale(ksandr|xei) Navalni?y"),
            Contact('Alisher Usmanov', 'Uzbeki oligarch with alleged ties to Putin, organized crime'),
            Contact('Andrey Vavilov', 'former Russian finance minister accused of stealing $230 million and other frauds'),
            Contact(
                ANYA_RASULOVA,
                f'Uzbeki co-founder of {INSIGHTS_POD}, social media work for Epstein during 2016 US election',
                link_to_bio=SUBSTACK_INSIGHTS_POD,
            ),
            Contact('Dasha Zhukova', "art collector, daughter of Alexander Zhukov"),
            Contact(
                'Dmitry Rybolovlev',
                f"oligarch, purchased {DONALD_TRUMP}'s house",
                r"Rybolo(o?l?ev|vlev)",
                link_to_bio='https://en.wikipedia.org/wiki/Dmitry_Rybolovlev',
            ),
            Contact('Igor Zinoviev', f"Epstein's bodyguard, MMA fighter"),
            Contact('Len Blavatnik', 'oligarch', link_to_bio='https://en.wikipedia.org/wiki/Len_Blavatnik'),
            Contact('Mikhail Prokhorov', 'Russian-Israeli oligarch', link_to_bio='https://en.wikipedia.org/wiki/Mikhail_Prokhorov'),
            Contact('Mikheil Saakashvili', 'president of Georgia', r"Mikh[ae]il Saakashvili"),
            Contact('Nicholas Kovarsky', f"friend of {SERGEY_BELYAKOV}", r"Nic(k|holas) Kovarsky"),
            Contact('Oleg Boyko', 'oligarch'),
            Contact(
                'Oleg Deripaska',
                'oligarch with underage sex scandal history',
                link_to_bio='https://www.themoscowtimes.com/2025/06/19/investigative-report-alleges-links-between-billionaire-deripaska-and-prostitution-ring-involving-minors-a89503',
            ),
            Contact('Ruben Vardanyan', 'Armenian oligarch, former minister of breakawy province of Artsakh'),
            Contact('Semion Mogilevich', 'infamous Russian mafia boss'),
            Contact(
                "Serguei Beloussov",
                'technologist',
                r"Serg Bell|Serguei Beloussov",
                link_to_bio='https://en.wikipedia.org/wiki/Serg_Bell',
            ),
            Contact(
                'Serguei Kouzmine',
                'co-founder of QWave Capital and gambling copmany Ritzio Entertainment',
                link_to_bio='https://www.fintechv.com/team',
            ),
            Contact(
                SERGEY_BELYAKOV,
                "graduate of Russia's FSB academy (AKA \"a spy\"), head of the St. Petersburg Economic Forum",
                r"Sergey Belyako|Беляков Сергей|Сергей Беляков|Cepre(ct|il) [6BES][\w.]+|6(er|of)no\w+ [CE]\w+",
                link_to_bio='https://dossier.center/jeffreyepsteinrusconnect-en/',
            ),
            Contact('Sergey Lavrov', 'foreign minister under Putin'),
            Contact('Svetlana Pudina', 'assistant to Vladislav Doronin'),
            Contact(
                UMAR_DZHABRAILOV,
                f'oligarch who called {GHISLAINE_MAXWELL} his "soulmate", death by "suicide" 2026-03-02',
                r"Umar D(j|zh)abrailov",
                # https://jamestown.org/kadyrovs-chechen-network-in-moscow-2/
                link_to_bio='https://nypost.com/2026/03/02/world-news/russian-mogul-who-called-ghislaine-maxwell-his-soulmate-found-dead/',
                match_partial='both',
            ),
            Contact('Viktor Yanukovych', 'pro-Putin former president of Ukraine', r"Vi[ck]tor Yanukovych"),
            Contact('Vitaly Churkin', 'Russian ambassador to the United Nations'),
            Contact('Vladislav Doronin', f'oligarch, dated {NAOMI_CAMPBELL}'),
            Contact(
                YURI_MILNER,
                f'Russian-Israeli investor whom Epstein says is managing "Russian gangster money"',
                link_to_bio='https://www.nytimes.com/2017/11/05/world/yuri-milner-facebook-twitter-russia.html',
                match_partial='both',
            ),
            Contact('Yury Molodtsov', f"assistant to {MASHA_DROKOVA} {QUESTION_MARKS}"),
            organization('Alfa Bank', 'Russian bank often used by FSB', r"Alfa( Bank)?"),
            organization('Apoletto', f"VC firm associated with {YURI_MILNER}"),
            organization('Buryat', "Mongol ethnic group native to southeastern Siberia", r"Buryat[is]?"),
            organization('Day One Ventures', f"silicon valley venture fund run by {MASHA_DROKOVA}"),
            organization(
                'Quantum Wave Fund',
                f"venture fund associated with {MASHA_DROKOVA} focused on quantum stuff",
                r"(Quantum Wave|QWave) (Capital|Fund)",
            ),
            organization('Runa Capital', 'fund of Serguei Beloussov with investment from Steve Jurvetson and Frank Creer'),
            organization('Sberbank', 'Russian bank'),
            organization(
                'Wirecard',
                f"largest financial fraud in German history, connections to FSB and crypto, CFO Jan Marsalek is a fugitive in Russia",
                r"Wire\s?card( Bank)?",
                link_to_bio='https://www.newyorker.com/magazine/2023/03/06/how-the-biggest-fraud-in-german-history-unravelled',
            ),
            organization('Women Empowerment', f"organization started by Epstein's assistant {SVETLANA_POZHIDAEVA}"),
        ],
        patterns=[
            r"Bel[ao]rus(sian)?",
            r"Chernobyl",
            r"Crimea",
            r"(Dmitry )?(Kiselyov|Medvedev)",
            r"Di?mitry( Akhanov)?",
            r"Domodedovo",
            r"FSB",
            r"GRU",
            r"KGB",
            r"Kislyak",
            r"Kremlin",
            r"(Anastasia )?Kuznetsova",
            r"Lavrov",
            r"Lukoil",
            r"Minsk",
            r"Moscow",
            r"Muscovite",
            r"(Natalia )?Veselnitskaya",
            r"Novosibirsk",
            r"Omsk",
            r"Onexim",  # Prokhorov investment vehicle
            r"Revolut",
            r"Rakishev",
            r"Rosneft",
            r"RT",
            r"Rusnano( USA)?(,? Inc\.?)?",
            r"Russ?(ai|ia)n?( (federation|mafia|gangster))?",
            r"Serbian?",
            r"Sochi",
            r"S(ain)?t\.? Petersburg",
            r"Soviet( Union)?",
            r"USSR",
            r"Vlad(imir)?(?! Yudash)",
            r"(Vladimir )?Putin",
            r"Xitrans",
        ],
    ),
    HighlightedNames(
        label='russian girl',
        style='color(161)',
        contacts=[
            Contact('Aksana Samy', 'Russian girl'),
            Contact('Alena Davydenkova', 'Russian girl'),
            Contact('Alisa Khayrutdinova', 'Russian girl'),
            Contact('Alysia Riabenkova', 'Russian painter', r"Alesia|Alysia( Riabenkova)?|Riabenkova"),
            Contact(ANASTASIYA_SIROOCHENKO, '', r"Anastasiya( Siro(chenko)?)?"),
            Contact(ANNA_KASATKINA, 'Russian girl'),
            Contact(ALEKSANDRA_KARPOVA, f"{CRYPTO_PR_LAB} co-founder", r"Aleksandra Karpova"),
            Contact(DASHA_GRUPMAN, 'recruiter of girls for Epstein', r"Da(ry|sh)a Grupman"),
            Contact('Ekaterina Gusarova', f'AKA "Katya", Instagram model {QUESTION_MARKS}', r"(Ekaterina|Katya)? Gusm?arova"),
            Contact('Irina Vodolazova', 'Russian model', match_partial='both'),
            Contact(
                JULIA_SANTOS,  # TODO: Jmail says her email is julia.santos@hbs.edu
                "recruiter of girls from Ukraine for Epstein, possibly Harvard Business School student",
                link_to_bio='https://www.reddit.com/r/Epstein/comments/1qwbn5i/trafficker_julia_santos/',
                match_partial=None,
            ),
            Contact(
                KARYNA_SHULIAK,
                f"girlfriend to whom Epstein tried to leave $50 million and the island, alleged sham marriage to {JENNIFER_KALIN}",
                r"(Karyna|Карина|Кариша)( Shuliak)?",
                link_to_bio='https://www.lemonde.fr/en/international/article/2026/02/22/karyna-shuliak-was-jeffrey-epstein-s-last-partner-and-main-heiress-she-won-t-benefit-from-his-will_6750738_4.html',
            ),
            Contact(
                KIRA_DIKHTYAR,
                'AKA "Kira Prokhorova", very active recruiter',
                r"Kira (D(ikhtyar)?|Ki(ra|m)|Prokhorova?)",
                link_to_bio='https://x.com/FlippersUpNow/status/2020490996287443071',
            ),
            Contact(
                'Konstantin Ignatov',
                'OneCoin fraud, brother of billionaire crypto fugitive Ruja Ignatova',
                link_to_bio='https://en.wikipedia.org/wiki/Ruja_Ignatova',
            ),
            Contact('Krystyna Gwiazda', 'Russian girl'),
            Contact(
                MARIA_PRUSAKOVA,
                f"AKA Masha Prusso, former Olympic snowboarder, {CRYPTO_PR_LAB} co-founder, \"found ladies\" for Epstein",
                r"Ma(sha|riy?a) (Prusa?(kova|so))",
                # https://www.reddit.com/r/Epstein/comments/1qvsnqs/a_detailed_report_on_masha_prusso_aka_maria/
                link_to_bio='https://www.scamurai.io/p/epstein-files-suggest-ex-polygon',
            ),
            Contact(
                MASHA_DROKOVA,
                'AKA "Masha Bucher", silicon valley VC (Day One Ventures), publicist for QWave, former Putin Youth member, star of "Putin\'s Kiss"',
                r"(Marii?y?a|Masha) (Bucher|Drokova)",
                link_to_bio='https://davidzmorris.substack.com/p/i-found-epstein-i-just-didnt-realize',
            ),
            Contact(OLGA_PONOMAR_BECKER, 'Russian girl'),
            Contact(
                RENATA_BOLOTOVA,
                "former model, fund manager at New York State Insurance Fund, Рената Болотова",
                r"Renata Bolotova|Rena B|Renata Bo\w+|renbolotova|Ренат[ау]|Болотова",
                link_to_bio='https://x.com/Cryptadamist/status/1996965537478566063',
                match_partial='both'
            ),
            Contact(
                'Ruslana Korshunova',
                "Russian model who visited Epstein's island before falling to her death in 2008",
                link_to_bio='https://en.wikipedia.org/wiki/Ruslana_Korshunova',
                match_partial='both',
            ),
            Contact(SANITA, "Russian girl who blew upat Epstein when he suggeted a massage"),
            Contact(
                SVETLANA_POZHIDAEVA,
                f"AKA 'Sophia Platt', Epstein assistant, went to FSB feeder school MGIMO, visa recommended by {SERGEY_BELYAKOV} (FSB) & {DAVID_BLAINE}",
                r"Sophia Platt|((Svet)?Lana )?Pozhidaeva|\b(Lana|Svet)\b|p\.selana|Selana P\b|Svetlan(?! Pudina)",
                link_to_bio='https://dossier.center/jeffreyepsteinrusconnect-en/',
                match_partial=None,
            ),
            Contact(YULIA_DOROKHINA, 'Russian girl, recruiter'),
            Contact('Yulia Trubuckai', 'Russian girl'),
            organization('George Models', 'based in Odessa, very young girls, basically a porn site'),
        ],
        patterns=[
            r"[DM]asha",
            r"[JY]ulia",
            r"Svetl?ana",
        ]
    ),
    HighlightedNames(
        label='Asia',
        style='light_salmon3 bold',
        contacts=[
            Contact(
                MOHAMED_WAHEED_HASSAN,
                "former president of the Maldives",
                r"Mohamed Waheed( Hassan)?",
                match_partial=None,
            ),
        ],
        patterns=[
            r"Austrai?lian?(?! Ave)",
            r"Bangkok",
            r"Burm(a|ese)",
            r"Cambodian?",
            r"Hanoi",
            r"Indonesian?",
            r"Kari Lai",
            r"Laos",
            r"Malaysian?",
            r"Male?dives",
            r"Myan?mar",
            r"New Zealand",
            r"(?<!North\s)(South\s*)?Korean?",
            r"Pacific Rim",
            r"Philippines",
            r"Sam\s?sung",
            r"Tai(pei|wan)",
            r"Thai(land)?",
            r"Vietnam(ese)?",
            # Japan
            r"BOJ",
            r"(Bank of )?Japan(ese)?",
            r"jpy?(?! Morgan)",
            r"SG",
            r"Singapore",
            r"Toky[op]",
        ],
    ),
    HighlightedNames(
        label=TECH_BRO,
        style='bright_cyan',
        contacts=[
            Contact('Alisa Bekins', f"{PETER_THIEL}'s assistant"),
            Contact(ANDREW_MCCORMACK, f"co-founder of {THIELS_VALAR}", r"Andrew McCorm(ack?)?"),
            Contact("Andy Rubin", "ex-Microsoft, ex-Google, fired for #MeToo reasons", match_partial=None),
            Contact('Auren Hoffman', "CEO of SafeGraph (mobile device location data co.), LiveRamp", match_partial=None),
            Contact(
                BOBBY_KOTICK,
                'CEO of video game titan Activision Blizzard ("Call of Duty", "World of Warcraft", etc.)',
                r"Kotick, Bobby|Bobby Kotick",
                link_to_bio='https://www.gamespot.com/articles/epstein-files-reveal-gaming-connections-plans-to-buy-activision-stock/1100-6537858/',
            ),
            Contact(CHAMATH_PALIHAPITIYA, f"{ALL_IN_PODCAST}, Facebook, crypto enthusiast, SPAC grifter, Trump convert", match_partial='both'),
            Contact(CHRIS_POOLE, 'AKA "Moot", founder of 4chan, ex-Google', r"mmot|Chris Poole?|(?-i:Moot)", link_to_bio='https://4chan.org/', match_partial=None),
            Contact('Danny Hillis', "computer scientist, artificial intelligence researcher", r"Dan(iel|ny) Hillis?"),
            Contact(
                'David Sacks',
                f"Craft Ventures, {ALL_IN_PODCAST}, anti-Ukraine / pro-Russia VC with connections to Wirecard",
                link_to_bio='https://www.thecaptainslog.io/the-david-sacks-files-part-i/',
                match_partial=None,
            ),
            Contact('Drew Houston', 'CEO of Dropbox', match_partial=None),
            Contact(
                ELON_MUSK,
                "father of Mecha-Hitler",
                link_to_bio='https://www.npr.org/2025/07/09/nx-s1-5462609/grok-elon-musk-antisemitic-racist-content',
                match_partial='both'
            ),
            Contact(
                'Frank Creer',
                'CEO of Draper Hero Institute alleged to be a sexual blackmailer by the Secret Service',
                r"Frank( Moyle)? Creer",
                link_to_bio='https://x.com/Cryptadamist/status/2027175564444930286',
            ),
            Contact(GEORGE_VRADENBURG, 'AOL/Time Warner General Counsel (top lawyer)'),
            Contact(HONGBO_ROBERT_BAO, THIELS_VALAR, r"Hong,? Robert Bao|Hongbo( Robert)? Bao"),
            Contact(HOSAIN_RAHMAN, 'CEO of Jawbone', match_partial='first'),
            Contact(IAN_ODONNELL, THIELS_VALAR, r"Ian O'?Donnell|O'?Donnell, Ian"),
            Contact('Jack Dorsey', 'co-founder of Twitter and Block (FKA Square)'),
            Contact(JAMES_FITZGERALD, f"co-founder of {THIELS_VALAR}", r"James Fitz[g\s]eral?d?", match_partial=None),
            Contact(
                JASON_CALACANIS,
                f'{ALL_IN_PODCAST} with David Sacks and {CHAMATH_PALIHAPITIYA}, Uber investor',
                r"Jason (.{12})?Calacanis",
                link_to_bio='https://en.wikipedia.org/wiki/Jason_Calacanis',
            ),
            Contact(
                KIMBAL_MUSK,
                f"brother of {ELON_MUSK}, dated Epstein's girl {JENNIFER_KALIN}",
                r"Kimball?( Musk)?",
                link_to_bio='https://www.theguardian.com/us-news/2026/feb/10/jeffrey-epstein-tesla-kimbal-musk',
                match_partial='first',
            ),
            Contact(MASAYOSHI_SON, 'CEO of Softbank, often referred to as "Masa"', r"Masa(yoshi)?(\sSon)?", match_partial='first'),
            Contact(MELANIE_PHILLIPS, f'girlfriend of {STEVEN_SINOFSKY}', match_partial=None),
            Contact('Nathan Myhrvold', f"former CTO of Microsoft, co-founder of Intellectual Ventures"),
            Contact(
                PETER_THIEL,
                f"Paypal mafia, Palantir co-founder, Facebook investor, Epstein invested ~$40 million in his fund {VALAR_VENTURES}",
                r"(Peter )?Th(ie|ei)l",
                link_to_bio='https://www.nytimes.com/2026/02/05/business/epstein-investments-palantir-coinbase-thiel.html',
            ),
            Contact('Philippe Laffont', f"founder of Coatue Management"),
            Contact(PHILIP_ROSEDALE, 'Second Life founder', link_to_bio='https://en.wikipedia.org/wiki/Philip_Rosedale'),
            Contact('Rajeev Misra', "formerly Softbank Vision Fund executive", r"[NR]ajeev"),
            Contact(REID_HOFFMAN, "PayPal mafia member, founder of LinkedIn, Democrat donor", match_partial=None),
            Contact('Reuben Kobulnik', THIELS_VALAR),
            Contact('Saida Sapieva', f'maybe assistant to {REID_HOFFMAN} {QUESTION_MARKS}'),
            Contact('Talia Parnass', f"{PETER_THIEL}'s assistant"),
            Contact(TED_LEONSIS, 'AOL executive, owner of Monumental Sports (Wizards, Capitals)'),
            Contact(
                VINCENZO_IOZZO,
                "CEO of the identity-security company SlashID",
                r"Vincenzo [IL]ozzo",
                link_to_bio='https://techcrunch.com/2026/02/12/hacker-linked-to-epstein-removed-from-black-hat-cyber-conference-website/',
                match_partial='both',
            ),
            Contact(
                ZUBAIR_KHAN,
                f"InsightsPod social media work on 2016 US election for Epstein, Islamabad/Dubai, friend of {MARIA_PRUSAKOVA}, Tranchulas cybersecurity",
                link_to_bio=SUBSTACK_INSIGHTS_POD,
                match_partial='both',
            ),
            organization('Accel Partners', 'venture capital firm', r"Accel( Partners)?"),
            organization('bgC3', 'renamed "Bill Gates Ventures" in 2018'),
            organization(
                'Coatue Management',
                "VC fund founded by Philippe Laffont possibly invested in by Epstein",
                r"Coatue( (Enterprises?|Management|Mgmt))?",
            ),
            organization('Coursera', is_emailer=True, is_interesting=False),
            organization(GOOGLE_PLUS, "Google Plus", r"Google\+", is_emailer=True, is_interesting=False),
            organization('Greylock', 'O.G. silicon valley venture capital firm', r"Greylock( Partners)?"),
            organization(
                'Honeycomb Asset Management',
                'venture fund Epstein invested in Spotify through',
                r"Honeycomb( (Offshore Fund|Partners)( (LP|Ltd))?)?",
            ),
            organization('Jawbone', f'wireless earpiece company invested in by Epstein and {IAN_OSBORNE}'),
            organization('LinkedIn', "LinkedIn", r"Linked[Il]n( Updates)?", is_emailer=True, is_interesting=False),
            organization('Match.com', 'dating site', r"match\.com|matchmail", is_emailer=True),
            organization('Mozilla', 'maker of the Firefox browser', r"Mozilla( Corp(oration)?)?"),
            organization('MySpace', "early social media, Epstein's creeptastic account data was lost", r"(www\.?)myspace(\.?com)?"),
            organization('Number26', f'fintech frontend for Wirecard Bank, renamed "N26"', r"N(umber)?26"),
            organization('Pandora', is_interesting=False, is_emailer=True),
            organization('Parler', 'twitter clone on which the January 6th attacks were coordinated', r"(?-i:P)arler"),
            organization(
                'Second Life',
                f"virtual world with early attempt at virtual currency the Linden Dollar",
                r"Second Life",
                link_to_bio='https://law.stanford.edu/stanford-lawyer/articles/this-is-not-a-game-law-and-order-in-virtual-worlds/',
            ),
            organization('Softbank Vision Fund', "Masayohsi Son's fund focused on tech, AI, WeWork", r"Softbank|(Softbank )?Vision Fund"),
            organization('Tarana Wireless', 'broadband provider', r"Tarana( (Technology|Wireless))?"),
            organization('ThielCapital', f"{PETER_THIEL} organization"),
            organization('Transferwise', 'fintech'),
            organization(VALAR_VENTURES, f"{PETER_THIEL} affiliated fintech venture fund", r"V[ae]lar( (Global Fund|Ventures?))?", is_emailer=True),
            organization('Wearality', f"startup invested in by Epstein and {JOI_ITO}", r"Wearality( Corporation)?"),
            organization(
                'WeWork',
                'infamously stupid failed temporary office space company',
                link_to_bio='https://www.theguardian.com/business/2023/nov/06/wework-bankruptcy-rise-fall',
            ),
        ],
        patterns=[
            r"4chan",
            r"Eliezer Yudkowsky",
            r"Erick? Sc?hmidt",
            r"(Jeff )?Bezos",
            r"Larry Page",
            r"Lytro",  # a16z co.
            r"(Mark )?Zuckerberg",
            r"Najeev",
            r"Palantir",
            r"Paul Allen",
            r"Pierre Omidyar",
            r"Sergey Brin",
            r"Spotify",
            r"SpaceX",
            r"Spotify",
            r"(Steve )?Ballmer",
            r"Tencent",
            r"Tesla",
            r"Tim Ferriss?",
            r"WikiLeak(ed|s)",
        ],
    ),
    HighlightedNames(
        label='techco',
        style='color(117)',
        category=TECH_BRO,
        patterns=[
            r"Activision( Blizzard)?",
            r"AG?I",
            r"(?-i:A)pple",
            r"Artificial (General )?Intelligence",
            r"Blizzard Entertainment",
            r"Cash App?",
            r"Cisco",
            r"cyber( (security|space))?",
            r"deep learning",
            r"Dropbox",
            r"Facebook",
            r"fintech",
            r"Google",
            r"Instagram",
            r"(?-i:I)ntel",
            r"Microsoft",
            r"MSFT",
            r"Overstock(.com)?",
            r"Paypal",
            r"quantum comput(er|ing)",
            r"Silicon Valley",
            r"Sony",
            r"SkyNet",
            r"Skyp(ed?|ing)",
            r"Tim Cook",
            r"Twitter",
            r"Uber",
            r"WhatsApp",
            r"(?-i:Y)ahoo",
        ],
    ),
    # aquamarine1
    HighlightedNames(
        label='Trump',
        style='red3 bold',
        contacts=[
            Contact(
                'Alan Weisselberg',
                f"Donald Trump's accountant",
                r"(Alan )?Weiss?e?lberg",
                link_to_bio='https://manhattanda.org/d-a-bragg-allen-weisselberg-sentenced-to-5-months-in-jail/',
            ),
            Contact('Bruce Moskowitz', "'Trump's health guy' according to Epstein", match_partial=None),
            Contact('Marla Maples', 'ex-wife of Donald Trump', match_partial='both'),
            Contact(
                'Melania',
                "...Trump?",
                r"Melania",
                link_to_bio='https://www.politico.com/newsletters/playbook/2021/10/15/models-and-bottles-when-melanias-pal-paolo-blew-through-dc-494719',
            ),
            Contact(
                'Michael Caputo',
                'former Putin and Gazprom PR guy, Trump appointee, acolyte of Roger Stone',
                link_to_bio='https://en.wikipedia.org/wiki/Michael_Caputo',
            ),
            Contact(NICHOLAS_RIBIS, f"Hilton CEO, former president of {TRUMP_ORG}", r"Nic(holas|k)[\s._]Ribi?s?|Ribbis"),
            Contact(
                'Paul Manafort',
                'Trump campaign manager, partner of Roger Stone, worked for Russians in Ukraine, convicted of financial fraud',
                link_to_bio='https://en.wikipedia.org/wiki/Trials_of_Paul_Manafort',
            ),
            Contact(
                'Roger Stone',
                "infamous political trickster with a tattoo of Nixon's face on his back",
                link_to_bio='https://en.wikipedia.org/wiki/Roger_Stone',
                match_partial=None,
            ),
        ],
        patterns=[
            r"@?realDonaldTrump",
            r"Alex Jones",
            r"(Brad(ley)? )Parscale",
            r"\bDJ?T\b",
            r"Donald J. Tramp",
            r"(Donald\s+(J\.\s+)?)?Trump(ism| (Org(anization)?|Properties)( LLC)?)?",
            r"Don(ald| Jr)(?! (B|Norman|Rumsfeld|Rubin))",
            r"(Hope )?Hicks",
            r"Ivank?a",
            r"Jared", r"(?<!Tony )Kushner",
            r"(Madeleine )?Westerhout",
            r"Mar[-\s]*a[-\s]*Lago",
            r"(Matt(hew)? )?Calamari",
            r"\bMatt C\b",
            r"Michael (D\.? )?Cohen",
            r"(Michael (J.? )?)?Boccio",
            r"Paul Rampell",
            r"Rebekah Mercer",
            r"rona",
            r"(The )?Art of the Deal",
        ],
    ),
    HighlightedNames(
        label='USVI',
        style='sea_green1',
        contacts=[
            Contact(CECILE_DE_JONGH, "Virgin Islands first lady 2007-2015, Epstein office manager"),
            Contact(KENNETH_E_MAPP, "Virgin Islands Governor"),
            Contact(STACEY_PLASKETT, "Virgin Islands non-voting member of Congress"),
            acronym('British Virgin Islands', 'infamous offshore tax haven'),
        ],
        patterns=[
            r"Antigua",
            r"Bahamas",
            r"Carr?ibb?ean",
            r"Cayman Islands?",
            r"Cura[cç]ao",
            r"Dominica(n Republic)?",
            r"(Great|Little) St.? James",
            r"Haiti(an)?",
            r"Jamaican?",
            r"(John )deJongh( Jr\.?)",
            r"Martinique",
            r"PBI",
            r"(?<!Bank\sof\s)Pu?erto\s*Ric(an|o)",
            r"San Juan",
            r"S(ain)?t\.? Thomas",
            r"USVI",
            r"U(nited |\.)?S(tates|\.)? Virgin Islands",
            r"(?<!stein |vis-a-)VI(?!s-a-)",
            r"(The )?Virgin Is(al|la)nd?s( Daily News)?",  # TODO: Hard to make this work right
            r"(West )?Palm Beach( County)?(?! (Daily|Police|Post))",
        ],
    ),
    HighlightedNames(
        label=Interesting.GIRLS,
        style=VICTIM_COLOR,
        contacts=[
            Contact('Aleksandra Eriksson', QUESTION_MARKS),
            Contact(
                JENNIFER_KALIN,
                f"involved in an alleged sham marriage to {KARYNA_SHULIAK}, dated {KIMBAL_MUSK}",
                link_to_bio='https://x.com/JOKAQARMY1/status/2026731420832481549',
            ),
            Contact('Jeanne Palfrey', '"The DC Madam", murdered'),
            Contact('Jennifer Aros', 'abused by Epstein starting at age 14', link_to_bio='https://x.com/epsteinsearchin/status/2031730091827544180'),
            Contact(KATHERINE_KEATING, "daughter of former Australian prime minister Paul Keating", match_partial=None),
            Contact('Miranda', f'appears to have done an internship at {CLIFFORD_CHANCE} with {MARIA_PRUSAKOVA}?'),
            Contact(PAULA_HEIL_FISHER, "Epstein's ex-girlfriend who works in opera now", match_partial=None),
            # Contact('Regina E. Frangul', f'Amex travel agent {QUESTION_MARKS}'),
            Contact('Samantha Rose Stein', 'wombkind.com', link_to_bio='https://x.com/SteinSamantha', match_partial=None),
            Contact('Sasha Grey', 'porn star', match_partial=None),
            Contact(UNKNOWN_GIRL, match_partial=None),
            Contact(
                'Virginia Giuffre',
                f"one of Epstein's first public accusers, died by suicide",
                r"(Virginia ((L\.?|Roberts) )?)?Giuffre",
                link_to_bio='https://en.wikipedia.org/wiki/Virginia_Giuffre',
            ),
        ],
        patterns=[
            r"abortion",
            r"ballerina",
            r"Beautify and the Beast",
            r"butt plug",
            r"(child )?porn(ography)?",
            r"Cinderella",
            r"condom",
            r"dancer",
            r"dildo",
            r"(?<!drug )(child\s*)?(sex\s*)?traffi?c?k(ers?|ing)",
            r"Ellaina As?tras?",
            r"((blonde?|fresh|hot|naughty|new|pretty|school|underage|young) )*girl( friend)?",
            r"gyn(eco(logist|nomist)|o)",
            r"I love you",
            r"ig(ni|ru)shki",
            r"intercourse",
            r"(Jane|Tiffany) Doe",
            r"Katie Johnson",
            r"lingerie",
            r"marri(age|ed)",
            r"Marta",
            r"massag(e(d|use)?s?|ing)( table)?",
            r"(Midget )?strippers?",
            r"Minor Victim",
            r"orgasm(ic|s)?",
            r"pa?edophile",
            r"pregnan(cy|t)",
            r"prostitut(e|ion)",
            r"pussy",
            r"Regina(?! Dugan)",
            r"(rough )?sex(ual(ity)?| (machine|toy))?",
            r"(rubber )?penis(es)?",
            r"(?-i:S)anctum",
            r'sexysearch2010',
            r"Snow White",
            r"sophiembh",
            r"Stephanie Clifford",
            r"(?-i:S)ue\b",  # Only in brock emails really?
            r"Stormy Daniels",
            r"strange women",
            r"teenager?",
            r"Tinkerbell",
            r"underage",
            r"vibrator",
            r"you are preg",
            VICTIM_DIARY,
            r"way better than supplying you ladies",
        ],
    ),
    HighlightedNames(
        label=VICTIM_LAWYER,
        style='medium_orchid1',
        contacts=[
            Contact('Alan P. Fraade', f'lawyer for {STEVEN_HOFFENBERG}'),
            Contact(BRAD_EDWARDS, ROTHSTEIN_ROSENFELDT_ADLER_ATTORNEY, r"Brad(ley)?( J(.?|ames))? Edwards", match_partial=None),
            Contact('David Boies', 'Boies, Schiller, & Flexner', r"(David )?Bo[il]es(,? Schiller( & Flexner)?)?"),
            Contact(DOUGLAS_WIGDOR, WIGDOR_ATTORNEY, r"Doug(las)? (H\.?)? Wigdor", match_partial=None),
            Contact(GLORIA_ALLRED, "victim's lawyer on many well known sexual harassment cases"),
            Contact('Grant J. Smith', ROTHSTEIN_ROSENFELDT_ADLER_ATTORNEY, match_partial=None),
            Contact(JEANNE_M_CHRISTENSEN, WIGDOR_ATTORNEY),
            Contact(JACK_SCAROLA, "Searcy Denney Scarola Barnhart & Shipley attorney"),
            Contact(KEN_JENNE, ROTHSTEIN_ROSENFELDT_ADLER_ATTORNEY),
            Contact(LAURA_A_MENNINGER, 'Haddon, Morgan and Foreman P.C.'),
            Contact(PAUL_G_CASSELL, 'professor at University of Utah, victim advocate'),
            Contact(STANLEY_POTTINGER, f"{VIRGINIA_GIUFFRE} legal team while working for Epstein", r"(J\.? )?(Stan(ley)? )?Pottinger"),
            organization('Marsh Law Firm', 'victim counsel'),
            organization('Mintz Fraade', f'law firm working for {STEVEN_HOFFENBERG}'),
            organization(
                ROTHSTEIN_ROSENFELDT_ADLER,
                "shady law firm, Rothstein ran $1.2 billion Ponzi scheme & was Roger Stone's partner",
                r"Rothstein,? Rosenfeldt,? Adler",
                link_to_bio='https://en.wikipedia.org/wiki/Scott_W._Rothstein',
            ),
            organization('Wigdor Law', f"sued {LEON_BLACK} alleging crimes at Epstein's properties", r"Wigdor(Law)?( LLP)?"),
        ],
        patterns=[
            r"(Mi(chael|ke) )?Avenatti",
            r"Rosenfeldt",
            r"(Scott )?Rothstein",
        ],
    ),
    HighlightedNames(
        label=STEVE_BANNON,
        style='color(58)',
        category='Republican',
        contacts=[
            Contact(SEAN_BANNON, f"{STEVE_BANNON}'s brother", r"sean bannon?", match_partial=None),
            Contact(
                STEVE_BANNON,
                f"{BROCK_PIERCE} biz partner (video game gold), Trump campaign manager, memecoin grifter, Epstein bestie",
                r"steve banno[nr]?",
                link_to_bio='https://cryptadamus.substack.com/p/the-epsteincrypto-timeline-is-alarming',
            ),
            organization('Biosphere', f'closed loop science experiment to mimic the earth in the 90s overseen by {STEVE_BANNON}'),
        ],
        patterns=[
            r"Arnold Schwarzenegger",
            r"(American )?Dharma",
        ],
    ),
    HighlightedNames(
        label=REAL_ESTATE,
        style='spring_green3',
        contacts=[
            Contact('André Balazs', 'hotelier, CEO of André Balazs Properties', r"Andre Bala(sz|zs)"),
            Contact('Anthony Barrett', "Ossa Properties (Mark Epstein company)", match_partial=None),
            Contact('Daniel Rosenberg', 'real estate developer', match_partial=None),
            Contact(
                DAVID_MITCHELL,
                "New York real estate developer, Mitchell Holdings",
                r"David( J\.?)? Mitchell",
                match_partial=None,
            ),
            Contact(GERALD_BARTON, "Maryland property developer Landmark Land Company", r"(?<!Wes )Barton"),
            Contact('Jed Garfield', 'high end real estate agent for Russians etc.', match_partial=None),
            Contact('Kira Titenva', 'real estate agent'),
            Contact(
                MARC_LEON,
                "Epstein's realtor in Morocco, Luxury Properties Sari",
                r"Marc[.\s]+(Kensington|Leon)|Kensington2",
                match_partial=None,
            ),
            organization('Ossa Properties', f"{MARK_EPSTEIN} company"),
        ],
        patterns=[
            r"((five star|Hyatt) )?hotel( room)?",
            r"int[e=]rior design(er)?",
            r"landlord",
            r"Mandarin Oriental",
            r"properties",
            r"real estate( developer)?",
            r"(reverse )?mortgage",
            r"tenant",
        ]
    ),
    # Individuals
    HighlightedNames(
        contacts=[
            Contact(
                STEVEN_HOFFENBERG,
                "Epstein's partner in Towers Financial Ponzi scheme, did 18 years in prison",
                link_to_bio='https://en.wikipedia.org/wiki/Steven_Hoffenberg',
            )
        ],
        style='dark_olive_green3',
        category=Neutral.FINANCE,
        patterns=[r"(steven? )?hoffenberg?w?"],
    ),
    HighlightedNames(
        label='Ghislaine',
        style='deep_pink3',
        category='Epstein',
        contacts=[
            Contact(BOBBI_C_STERNHEIM, f"{GHISLAINE_MAXWELL}'s {CRIMINAL_DEFENSE_ATTORNEY}"),
            Contact(
                CHRISTIAN_EVERDELL,
                f"{GHISLAINE_MAXWELL}'s lawyer ca. 2021, Cohen & Gresser",
                r"C(hristian )?Everdell?",
            ),
            Contact('Emmy Tayler', f"{GHISLAINE_MAXWELL}'s personal assistant"),
            Contact(
                GHISLAINE_MAXWELL,
                "Epstein's girlfriend, daughter of the spy Robert Maxwell",
                r"g max(1@ellmax.com|well)?|Ghislai?ne|Maxwell",
                link_to_bio='https://en.wikipedia.org/wiki/Ghislaine_Maxwell',
            ),
            Contact('Isabel Maxwell', f"sister of Ghislaine, wife of {AL_SECKEL}", match_partial=None),
            Contact(
                'Robert Maxwell',
                f"father of Ghislaine, British / Russian / Israeli agent, financial fraudster, mysterious death",
                link_to_bio='https://en.wikipedia.org/wiki/Robert_Maxwell',
                match_partial=None,
            ),
            Contact('Scott Borgenson', f"boyfriend (and lawyer?) of {GHISLAINE_MAXWELL}"),
            Contact('Ted Waitt', f"boyfriend of {GHISLAINE_MAXWELL}, guest at Chelsea Clinton wedding"),
            organization(
                "The Terramar Project",
                f"clean oceans environmental nonprofit launched by {GHISLAINE_MAXWELL} for reputation repair",
                r"(The )?TerraMar( Project)?",
            ),
        ],
    ),
    HighlightedNames(
        contacts=[
            Contact(
                HAMAD_BIN_JASSIM,
                " AKA \"HBJ\", former Qatari prime minister, planned Sharia crypto with Epstein",
                r"[ji]abor y?|labor y|HBJ|Hamad bin Jassim( al-Thani)?",
                link_to_bio='https://en.wikipedia.org/wiki/Hamad_bin_Jassim_bin_Jaber_Al_Thani',
                match_partial=None,
            ),
        ],
        category=MIDEAST,
        style='spring_green1',
    ),
    HighlightedNames(
        contacts=[
            Contact(
                KATHRYN_RUEMMLER,
                "former Obama legal counsel",
                r"Kathr?yn? (H\.? )?Ruemmler?",
                link_to_bio='https://www.ft.com/content/1fdb1850-7ff8-4ca5-bc91-f4b683aad063',
            ),
        ],
        style='magenta2',
        category=FRIEND
    ),
    HighlightedNames(
        contacts=[Contact(MELANIE_WALKER, f"doctor, friend of {BILL_GATES}", match_partial=None)],
        style='pale_violet_red1',
        category=FRIEND
    ),
    HighlightedNames(
        contacts=[
            Contact(
                PRINCE_ANDREW,
                "British royal family",
                r"Prince Andrew|The Duke",
                link_to_bio='https://www.cnn.com/world/live-news/andrew-mountbatten-windsor-arrested-uk-police-02-19-26',
                match_partial=None,
            )
        ],
        patterns=[
            r'\b(?<!FOI/)PA\b',
            r"(?<!Cantor )Urramoor(\s*Limited)?",
            r"Mr\. T",
        ],
        style='dodger_blue1',
        category='Europe',
    ),
    HighlightedNames(
        contacts=[
            Contact(
                SOON_YI_PREVIN,
                f"former adopted daughter of / now married to {WOODY_ALLEN}",
                r"Soon Yi Previn?",
                match_partial='both'
            ),
        ],
        style='hot_pink',
        category=ARTS
    ),
    HighlightedNames(
        contacts=[
            Contact(
                SULTAN_BIN_SULAYEM,
                "chairman of ports in Dubai, CEO of DP World, resigned over Epstein ties",
                r"Sultan (Ahmed )?bin Sulaye?m?|ssulayem[©@a](aol|etisalat\.?blackberry).com",
                link_to_bio='https://www.bbc.com/news/articles/ce82xgd2g3yo',
            )
        ],
        style='green1',
        category=MIDEAST
    ),

    # HighlightedText not HighlightedNames bc of word boundary (\b) issue with '#', '(', etc.
    HighlightPatterns(
        label='metoo',
        style=VICTIM_COLOR,
        patterns=[r"#metoo"]
    ),
    HighlightPatterns(
        label='dollars',
        style=FINANCIAL_COLOR,
        patterns=[
            r"\$[\dO,.]+(\s*(bn|[bm](illl?ion|m)?|k|thousand))?( dollars?)?",
            r"[\d,.]+\s*[bm]illl?ion( dollars?)?( loan)?",
        ]
    ),
    HighlightPatterns(
        label='unknown',
        style='cyan',
        patterns=[r'\(unknown\)']
    ),

    # Highlight regexes for things other than names, only used by RegexHighlighter pattern matching
    HighlightPatterns(
        label='financial',
        style=FINANCIAL_COLOR,
        use_word_boundary=True,
        patterns=[
            r"accountant",
            r"accounting firm",
            r"American Express",
            r"Amex",
            r"alterna[tv]i[tv]e finance",
            r"((anti )?money )?launder(s?|ers?|ing)?( money)?",
            r"(?<!(alfa|ture|hase|rahi|sche)\s)bank(?!\s+(of|secrecy))",
            r"Black Sc?holes",
            r"brokerage",
            r"capital controls",
            r"C[EF]O",
            r"charit(ies|y)",
            r"Chief (Executive|Financ(e|ial)) Officer",
            r"(co-?)?founder",
            r"convertible note",
            r"donor advised fund",
            r"EBITDA",
            r"equities",
            r"hedge fund",
            r"(?<!Kyara\s)invest(ment|or)s?(\sadvis[eo]r[sy]?)?",
            r"(junk )?bond",
            r"Managing Director",
            r"Mastercard",
            r"money",
            r"(naked )?shorting",
            r"NASDAQ",
            r"options trad(er|ing)",
            r"philanthrop(i(es|st)|y)",
            r"ponz[il] scheme",
            r"preferreds",
            r"Series (7|30)",
            r"securities(?! ((&|and) Exchange|fraud))",
            r"stock market",
            r"Trust(ee| Estate)s?",
            r"(income )?tax(e[ds])?( code)?",
            r"(?-i:VAT)",
            r"Wall Street(?! Jour)",
        ]
    ),
    HighlightPatterns(
        label='legal',
        style='pale_turquoise4',
        use_word_boundary=True,
        patterns=[
            r"affidavit",
            r"autopsy",
            fr"^{CASE_ID_REGEX.pattern}.*",
            CASE_ID_REGEX.pattern,
            r"deposition",
            r"EDGAR (Filing|Search)",  # SEC database is EDGAR
            r"(federal|state) judge",
            r"General Counsel",
            r"lawyer",
            r"Notary Public",
            r"Page \d+ of \d+",
            r"testimony",
        ]
    ),
    HighlightPatterns(
        label='locations',
        style='cornsilk1',
        use_word_boundary=True,
        patterns=STATE_NAME_PATTERNS + [
            r"Arizona(?! State U)",
            r"Aspen",
            r"Berkeley",
            r"Boca Raton",
            r"Boston",
            r"Brooklyn",
            r"Cape Cod",
            r"Charlottesville",
            r"(?<!District\sof\s)Florida",
            r"F(or)?t\.? Lauderdale",
            r"Jersey City",
            r"Los Angeles",
            r"Loudoun County?",
            r"Manhattan(?!\s+DA)",
            r"Martha's Vineyard",
            r"Miami(?!\s?Herald)",
            r"Nantucket",
            r"NY(C| State)",
            r"Orange County",
            r"Palo Alto",
            r"Phoenix",
            r"Portland",
            r"San Francisco",
            r"Santa Monica",
            r"Sant[ae] Fe",
            r"Telluride",
            r"Teterboro",
            r"Texas(?! A&M)",
            r"Toronto",
            r"Tu(sc|cs)on",
            r"Vancouver",
            r"Virginian?(?! (L\.?)? (Giuffre|Roberts))",
            r"Washington( D\.?C)?(?! Post)",
            r"Westchester",
        ],
    ),
    HighlightPatterns(
        label='phone_number',
        style='bright_green',
        patterns=[
            r"\+?(1?\(?\d{3}\)?[-\s]\d{3}[-\s]\d{4}|\d{2}[-\s]\(?0?\)?\d{2}[-\s]\d{4}[-\s]\d{4})",
            r"(\b|\+)[\d+]{10,12}\b",
        ],
    ),
     HighlightPatterns(
        label='header_field',
        style='plum4',
        patterns=[fr"^([>»•\s]{{,4}}({'|'.join(ALL_HEADER_PATTERNS)}):|on behalf of)"],
    ),
    HighlightPatterns(
        label='http_links',
        style=f'{ARCHIVE_LINK_COLOR} underline',
        patterns=[r"https?:[^\s]+"],
    ),
    HighlightPatterns(
        label='quoted_reply_line',
        style='dim',
        patterns=[
            REPLY_REGEX.pattern,
            r"^(Best|Cheers),?\nJeremy",
            r"^@JeremyRubin",
            r"^(> )?wrote:$",
            r"CONFIDENTIAL FOR ATTORNEY'S EYES ONLY(\nDO NOT COPY)?",
            r"PRIVILEGED - ATTORNEY WORK.*(\nCONFIDENTIAL - SUBJECT TO.*)?",
            r"Managing Partner - Crypto Currency Partners",  # brock pierce
            r"Please use this email for.*general Media Lab.*",  # Joi Ito
            r"-Austin\nAustin Hill - B..dder.*(\n.*B92ED3E3)?",  # Austin Hill
            r"^(Please note my new email address?:?.*|Follow me on twitter @[Il]hsummers|www.larrysummers.com)$", # larry summers
            r"^W dniu wt.*",  # Russian cyrillic
        ],
    ),
    HighlightPatterns(
        label='redacted',
        style='grey58',
        patterns=[fr"{REDACTED}|<?Privileged - Redacted>?"],
    ),
    HighlightPatterns(
        label='sent_from_device',
        style='light_cyan3 italic dim',
        patterns=[fr"{QUOTE_INDENT_CHAR_GROUP}*{SENT_FROM_REGEX.pattern}"],
    ),
    HighlightPatterns(
        label='snipped_signature',
        style='gray35 italic dim',
        patterns=[fr'<\.\.\.(snipped|trimmed).*\.\.\.>|{XML_STRIPPED_MSG}'],
    ),
    HighlightPatterns(
        label='timestamp_2',
        style=TIMESTAMP_STYLE,
        patterns=[
            fr"({DATE_PATTERN} )?{TIME_PATTERN}",
            fr"\b{DATE_PATTERN}\b",
        ],
    ),

    # Manual regexes
    ManualHighlight(
        label='email_attachments',
        style='gray30 italic',
        pattern=r"^(> )?(Attach(ed|ments)|[Il]nline-[Il]mages): (?P<email_attachments>.*)",
    ),
    ManualHighlight(
        label='email_timestamp',
        style=TIMESTAMP_STYLE,
        pattern=r"^(> )?(Date|Envoy[eé] ?|Sent): (?P<email_timestamp>.*)",
    ),
]

HIGHLIGHTED_NAMES = [hg for hg in HIGHLIGHT_GROUPS if isinstance(hg, HighlightedNames)]
HIGHLIGHTED_CONTACTS = flatten([hn.contacts for hn in HIGHLIGHTED_NAMES])


def get_contact(name: str) -> Contact | None:
    if (group := get_highlight_group_for_name(name)) and isinstance(group, HighlightedNames):
        return group.contacts_lookup.get(name)


def get_highlight_group_for_name(name: str | None) -> HighlightGroup | None:
    if not name:
        return None

    for highlight_group in HIGHLIGHT_GROUPS:
        if highlight_group.regex.search(name):
            return highlight_group


def get_style_for_category(category: str) -> str | None:
    """
    First check `CATEGORY_STYLES`, then check if there's a mapping in `CATEGORY_STYLE_MAPPING`,
    and finally just match the category name to the `HighlightedNames.label`.
    """
    if category in CATEGORY_STYLES:
        return CATEGORY_STYLES[category]

    for highlight_group in HIGHLIGHT_GROUPS:
        if highlight_group.label == CATEGORY_STYLE_MAPPING.get(category, category):
            return highlight_group.style


def get_style_for_name(name: str | None, default_style: str = DEFAULT_NAME_STYLE, allow_bold: bool = True) -> str:
    highlight_group = get_highlight_group_for_name(name or UNKNOWN)
    style = highlight_group.style if highlight_group else default_style
    style = style if allow_bold else style.replace('bold', '').strip()
    logger.debug(f"get_style_for_name('{name}', '{default_style}', '{allow_bold}') yielded '{style}'")
    return style


def styled_category(category: str | None) -> Text:
    if category:
        return Text(category.split('_')[0], get_style_for_category(category) or DEFAULT_CATEGORY_STYLE)
    else:
        return QUESTION_MARKS_TXT


def styled_name(name: str | None, default_style: str = DEFAULT_NAME_STYLE) -> Text:
    return Text(name or UNKNOWN, style=get_style_for_name(name, default_style=default_style))


def _print_highlighted_names_repr() -> None:
    for hn in HIGHLIGHTED_NAMES:
        print(indented(repr(hn)) + ',')
        print(f"pattern: '{hn.regex.pattern}'")

    import sys
    sys.exit()


if args.deep_debug:
    for c in HIGHLIGHTED_CONTACTS:
        print(repr(c))
